@@ -42,6 +42,7 @@ SHOW_AUDIO_FILES = 2
 SHOW_GRAPHICS_FILES = 3
 SHOW_IMAGE_SEQUENCES = 4
 SHOW_PATTERN_PRODUCERS = 5
+SHOW_UNUSED_FILES = 6
 
 # These are used to draw indicators that tell if more frames are available while trimming
 ON_FIRST_FRAME = 0
@@ -66,6 +67,7 @@ PROP_FLOAT = 1
 PROP_EXPRESSION = 2
 
 # Display heights for tracks and timeline.
+TRACK_HEIGHT_HIGH = 75 # track height in canvas and column
 TRACK_HEIGHT_NORMAL = 50 # track height in canvas and column
 TRACK_HEIGHT_SMALL = 25  # track height in canvas and column
 TRACK_HEIGHT_SMALLEST = 25 # maybe remove this as it is no longer used
@@ -144,11 +146,14 @@ CONVERTING_TO_USE_ORIGINAL_MEDIA = 3
 
 # Autosave directory relative path
 AUTOSAVE_DIR = "autosave/"
-AUDIO_LEVELS_DIR = "audiolevels/"
 
 # Hidden media folders
+# NOTE: We have not been fully consistant with the ending forward slashes.
+AUDIO_LEVELS_DIR = "audiolevels/"
+PROXIES_DIR = "proxies/"
 THUMBNAILS_DIR = "thumbnails"
 RENDERED_CLIPS_DIR = "rendered_clips"
+TLINE_RENDERS_DIR = "tlinerenders"
 GMIC_DIR = "gmic"
 PHANTOM_DIR = "phantom2d"
 PHANTOM_DISK_CACHE_DIR = "disk_cache"
@@ -156,7 +161,14 @@ MATCH_FRAME_DIR = "match_frame"
 MATCH_FRAME = MATCH_FRAME_DIR + "/match_frame.png"
 MATCH_FRAME_NEW = MATCH_FRAME_DIR + "/match_frame_new.png"
 TRIM_VIEW_DIR = "trim_view"
-NATRON_DIR = "natron"
+USER_PROFILES_DIR = "user_profiles/"
+USER_PROFILES_DIR_NO_SLASH = "user_profiles"
+BATCH_DIR = "batchrender/"
+CONTAINER_CLIPS_DIR = "container_clips"
+CONTAINER_CLIPS_UNRENDERED = "container_clips/unrendered"
+CC_CLIP_FRAMES_DIR = "/clip_frames"
+CC_RENDERED_FRAMES_DIR = "/rendered_frames"
+CC_PREVIEW_RENDER_DIR = "/preview_frames"
 
 # Luma bands
 SHADOWS = 0
@@ -201,14 +213,10 @@ SHORTCUTS_ROOT_TAG = 'flowblade'
 SHORTCUTS_TAG = 'shortcuts'
 
 # Project properties keys
-P_PROP_DISSOLVE_GROUP_FADE_IN = "P_PROP_DISSOLVE_GROUP_FADE_IN"
-P_PROP_DISSOLVE_GROUP_FADE_OUT = "P_PROP_DISSOLVE_GROUP_FADE_OUT"
-P_PROP_ANIM_GROUP_FADE_IN = "P_PROP_ANIM_GROUP_FADE_IN"
-P_PROP_ANIM_GROUP_FADE_OUT = "P_PROP_ANIM_GROUP_FADE_OUT"
 P_PROP_TLINE_SHRINK_VERTICAL = "tline_shrink_vertical"
 P_PROP_LAST_RENDER_SELECTIONS = "P_PROP_LAST_RENDER_SELECTIONS"
 P_PROP_TRANSITION_ENCODING = "P_PROP_TRANSITION_ENCODING"
-P_PROP_AUTO_FOLLOW = "P_PROP_AUTO_FOLLOW"
+P_PROP_DEFAULT_FADE_LENGTH = "P_PROP_DEFAULT_FADE_LENGTH"
 
 # A context defining action taken when mouse press happens based on edit mode ands mouse position
 POINTER_CONTEXT_NONE = 0
@@ -253,3 +261,37 @@ DND_ALWAYS_INSERT = 2
 # Top row layouts
 THREE_PANELS_IF_POSSIBLE = 0
 ALWAYS_TWO_PANELS = 1
+
+# Copypaste data tyoe
+COPY_PASTE_DATA_CLIPS = 1
+COPY_PASTE_DATA_COMPOSITOR_PROPERTIES = 2
+COPY_PASTE_KEYFRAME_EDITOR_KF_DATA = 3
+COPY_PASTE_GEOMETRY_EDITOR_KF_DATA = 4
+
+# Timeline Compositong modes
+COMPOSITING_MODE_TOP_DOWN_FREE_MOVE = 0
+COMPOSITING_MODE_TOP_DOWN_AUTO_FOLLOW = 1 # Deprecated, mode removed 2.6 ->
+COMPOSITING_MODE_STANDARD_AUTO_FOLLOW = 2
+COMPOSITING_MODE_STANDARD_FULL_TRACK = 3
+
+# Magic string for selection path being user home directory root
+USER_HOME_DIR = "USER_HOME_DIERCTORY_&&##&&"
+
+# Timeline rendering modes
+TLINE_RENDERING_OFF = 0
+TLINE_RENDERING_AUTO = 1
+TLINE_RENDERING_REQUEST = 2
+
+# Timeline rendering uses these now
+PROXY_SIZE_FULL = 0
+PROXY_SIZE_HALF = 1
+PROXY_SIZE_QUARTER = 2
+
+
+# Container clip types
+CONTAINER_CLIP_GMIC = 0
+CONTAINER_CLIP_MLT_XML = 1
+CONTAINER_CLIP_CAIRO_SCRIPT = 2
+CONTAINER_CLIP_BLENDER = 3
+
+CONTAINER_CLIP_VIDEO_CLIP_NAME = "container_clip"
