@@ -31,11 +31,13 @@ import time
 from gi.repository import Gtk, Gdk
 
 import appconsts
+import atomicfile
 import dialogutils
 from editorstate import PROJECT
 import gui
 import guiutils
 import updater
+import userfolders
 import utils
 
 # Frame level value cache for audio levels
@@ -55,14 +57,15 @@ def set_waveform_displayer_clip_from_popup(data):
     if clip.path in frames_cache:
         frame_levels = frames_cache[clip.path]
         clip.waveform_data = frame_levels
+        updater.repaint_tline()
         return
 
-    cache_file_path = utils.get_hidden_user_dir_path() + appconsts.AUDIO_LEVELS_DIR + _get_unique_name_for_media(clip.path)
+    cache_file_path = userfolders.get_cache_dir() + appconsts.AUDIO_LEVELS_DIR + _get_unique_name_for_media(clip.path)
     if os.path.isfile(cache_file_path):
-        f = open(cache_file_path)
-        frame_levels = pickle.load(f)
+        frame_levels = utils.unpickle(cache_file_path)
         frames_cache[clip.path] = frame_levels
         clip.waveform_data = frame_levels
+        updater.repaint_tline()
         return
 
     progress_bar = Gtk.ProgressBar()
@@ -101,7 +104,7 @@ class WaveformCreator(threading.Thread):
         threading.Thread.__init__(self)
         self.clip = clip
         self.temp_clip = self._get_temp_producer(clip)
-        self.file_cache_path = utils.get_hidden_user_dir_path() + appconsts.AUDIO_LEVELS_DIR + _get_unique_name_for_media(clip.path)
+        self.file_cache_path = userfolders.get_cache_dir() + appconsts.AUDIO_LEVELS_DIR + _get_unique_name_for_media(clip.path)
         self.track_height = track_height
         self.abort = False
         self.clip_media_length = self.temp_clip.get_length()
@@ -145,8 +148,9 @@ class WaveformCreator(threading.Thread):
 
         if not self.abort:
             self.clip.waveform_data = frame_levels
-            write_file = file(self.file_cache_path, "wb")
-            pickle.dump(frame_levels, write_file)
+            with atomicfile.AtomicFileWriter(self.file_cache_path, "wb") as afw:
+                write_file = afw.get_file()
+                pickle.dump(frame_levels, write_file)
 
             Gdk.threads_enter()
             self.dialog.progress_bar.set_fraction(1.0)
@@ -168,7 +172,7 @@ class WaveformCreator(threading.Thread):
         service = clip.get("mlt_service")
         if service.startswith("xml"):
             service = "xml-nogl"
-        temp_producer = mlt.Producer(PROJECT().profile, service.encode('utf-8'), clip.get("resource"))
+        temp_producer = mlt.Producer(PROJECT().profile, service, clip.get("resource"))
         channels = mlt.Filter(PROJECT().profile, "audiochannels")
         converter = mlt.Filter(PROJECT().profile, "audioconvert")
         self.levels = mlt.Filter(PROJECT().profile, "audiolevel")
@@ -185,7 +189,7 @@ def _waveform_render_progress_dialog(callback, title, text, progress_bar, parent
     dialog = Gtk.Dialog(title,
                          parent_window,
                          Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                         (_("Cancel").encode('utf-8'), Gtk.ResponseType.REJECT))
+                         (_("Cancel"), Gtk.ResponseType.REJECT))
 
     dialog.text_label = Gtk.Label(label=text)
     dialog.text_label.set_use_markup(True)
