@@ -26,10 +26,13 @@ import propertyedit
 import propertyparse
 
 """
-This module handles adding fade-ins and fade-outs to compositors.
+This module handles adding fade-ins and fade-outs to compositors and filters.
 
 Creating and managing keyframes is mostly handled by editor GUI components which cannot easily 
 be used for adding fade-ins and fade outs, so this dedicated module is needed.
+
+NOTE: This can all (maybe) be killed now and done more simply in keyframeeditor.py, original reasons for this existing
+may not apply anymore.
 """
 
 # Dissolve default fades group ("Dissolve", "Blend") keyframe property class names
@@ -42,9 +45,10 @@ def add_fade_in(compositor, fade_in_length):
     
     if fade_in_length > 0:
         if fade_in_length <= clip.clip_length():
-            _do_user_add_fade_in(keyframe_property, property_klass, keyframes, fade_in_length)
+            return _do_user_add_fade_in(keyframe_property, property_klass, keyframes, fade_in_length)
         else:
             _show_length_error_dialog()
+            return None
 
 def add_fade_out(compositor, fade_out_length):
     clip = _get_compositor_clip(compositor)
@@ -52,9 +56,26 @@ def add_fade_out(compositor, fade_out_length):
     
     if fade_out_length > 0:
         if fade_out_length + 1 <= clip.clip_length():
-            _do_user_add_fade_out(keyframe_property, property_klass, keyframes, fade_out_length, clip)
+            return _do_user_add_fade_out(keyframe_property, property_klass, keyframes, fade_out_length, clip)
         else:
             _show_length_error_dialog()
+            return None
+
+def add_filter_fade_in(clip, keyframe_property, keyframes, fade_in_length):   
+    if fade_in_length > 0:
+        if clip.clip_in + fade_in_length <= clip.clip_out:
+            return _do_user_add_fade_in_filter(keyframe_property, keyframes, fade_in_length, clip.clip_in)
+        else:
+            _show_length_error_dialog()
+            return None
+
+def add_filter_fade_out(clip, keyframe_property, keyframes, fade_out_length):   
+    if fade_out_length > 0:
+        if clip.clip_in + fade_out_length <=  clip.clip_out:
+            return _do_user_add_fade_out_filter(keyframe_property, keyframes, fade_out_length, clip)
+        else:
+            _show_length_error_dialog()
+            return None
 
 def set_auto_fade_in_keyframes(compositor):
     clip = _get_compositor_clip(compositor)
@@ -86,7 +107,9 @@ def set_auto_fade_out_keyframes(compositor):
     
 # ---------------------------------------------------------------------- module functions
 def _get_kfproperty_klass_and_keyframes(compositor, clip):
-    # Create editable properties from compositor properties.
+    # We create a SECOND SET of EditableProperties from compositor properties.
+    # These are not the same EditableProperties that are edited in GUI in "Compositor" panel.
+    # This approach seems necessery because Affine Blend requires creating a new property.
     t_editable_properties = propertyedit.get_transition_editable_properties(compositor)
 
     # Find keyframe property, its class and create keyframes list
@@ -131,16 +154,6 @@ def _get_compositor_clip(compositor):
     
     return None
 
-def _get_default_fades_lengths(property_klass):
-    if property_klass in _dissolve_property_klasses:
-        fade_in_length = editorstate.PROJECT().get_project_property(appconsts.P_PROP_DISSOLVE_GROUP_FADE_IN)
-        fade_out_length = editorstate.PROJECT().get_project_property(appconsts.P_PROP_DISSOLVE_GROUP_FADE_OUT) 
-    else:
-        fade_in_length = editorstate.PROJECT().get_project_property(appconsts.P_PROP_ANIM_GROUP_FADE_IN)
-        fade_out_length = editorstate.PROJECT().get_project_property(appconsts.P_PROP_ANIM_GROUP_FADE_OUT)
-    
-    return (fade_in_length, fade_out_length)
-
 def _add_default_fade_in(keyframe_property, property_klass, keyframes, fade_in_length):
     if property_klass in _dissolve_property_klasses:
         frame, opacity  = keyframes.pop(0)
@@ -196,16 +209,19 @@ def _do_user_add_fade_in(keyframe_property, property_klass, keyframes, fade_in_l
         if property_klass in _dissolve_property_klasses:
             frame, opacity  = keyframes.pop(0)
             keyframes.insert(0, (frame, 0))
-            keyframes.pop(1)
             keyframes.insert(1,(frame + fade_in_length, 100))
         else:
             # (0, [0, 0, 1280, 720], 100.0) or (0, [640.0, 360.0, 1.0, 1.0, 0.0], 100.0) e.g.
             frame, geom, opacity = keyframes.pop(0)
             keyframes.insert(0, (frame, geom, 0))
-            keyframes.pop(1)
             keyframes.insert(1, (frame + fade_in_length, geom, 100))
 
+    # Because we created a SECOND SET of EditableProperties this only updates data structures (py and MLT)
+    # but not EditableProperties wrappers that are edited in GUI in "Compositor" panel.
     keyframe_property.write_out_keyframes(keyframes)
+    
+    # We need to return updated keyframes to update GUI in "Compositor" panel.
+    return keyframes
 
 def _do_user_add_fade_out(keyframe_property, property_klass, keyframes, fade_out_length, clip):
     # Get index of first keyframe before fade out begins
@@ -234,9 +250,85 @@ def _do_user_add_fade_out(keyframe_property, property_klass, keyframes, fade_out
             
         keyframes = _add_default_fade_out(keyframe_property, property_klass, keyframes, fade_out_length, clip, len(keyframes) - 1)
 
+    # Because we created a SECOND SET of EditableProperties this only updates data structures (py and MLT)
+    # but not EditableProperties wrappers that are edited in GUI in "Compositor" panel.
     keyframe_property.write_out_keyframes(keyframes)
 
+    # We need to return updated keyframes to update GUI in "Compositor" panel.
+    return keyframes
 
+def _do_user_add_fade_in_filter(keyframe_property, keyframes, fade_in_length, clip_in):
+    # Get index of first keyframe after fade_in_length
+    kf_after_fade_in_index = -1
+    for i in range (0, len(keyframes)):
+        kf = keyframes[i]
+        frame, opacity  = kf
+        
+        if frame > clip_in + fade_in_length:
+            kf_after_fade_in_index = i
+            break
+
+    # Case no keyframes after fade in length
+    if kf_after_fade_in_index == -1:
+        # Remove all but first keyframe
+        for i in range(0, len(keyframes) - 1):
+            keyframes.pop(1)
+
+        frame, opacity  = keyframes.pop(0)
+
+        keyframes.append((clip_in, 0))
+        keyframes.append((clip_in + fade_in_length, 100))
+    # Case keyframes exists after fade in length
+    else:
+        # Remove keyframes in range 0 - kf_after_fade_in_index
+        for i in range(0, kf_after_fade_in_index - 1):
+            keyframes.pop(1)
+
+        frame, opacity  = keyframes.pop(0)
+        keyframes.insert(0, (clip_in, 0))
+        keyframes.insert(1, (clip_in + fade_in_length, 100))
+
+    # Because we created a SECOND SET of EditableProperties this only updates data structures (py and MLT)
+    # but not EditableProperties wrappers that are edited in GUI in "Compositor" panel.
+    keyframe_property.write_out_keyframes(keyframes)
+    
+    # We need to return updated keyframes to update GUI in "Compositor" panel.
+    return keyframes
+
+def _do_user_add_fade_out_filter(keyframe_property, keyframes, fade_out_length, clip):
+
+    # Get index of first keyframe before fade out begins
+    fade_out_frame = clip.clip_out - fade_out_length
+    kf_after_fade_out_index = -1
+    for i in range (0, len(keyframes)):
+        kf = keyframes[i]
+        frame, opacity  = kf
+
+        if frame >= fade_out_frame:
+            kf_after_fade_out_index = i
+            break
+
+    # Case no keyframes after fade out start
+    if kf_after_fade_out_index == -1:
+        keyframes.append((clip.clip_out - fade_out_length - 1, 100))
+        keyframes.append((clip.clip_out - 1, 0))
+
+    # Case keyframes exists after  fade out start
+    else:
+        # Remove keyframes in range 0 - kf_after_fade_in_index
+        for i in range(kf_after_fade_out_index, len(keyframes)):
+            keyframes.pop(-1) # pop last
+            
+        keyframes.append((clip.clip_out - fade_out_length - 1, 100))
+        keyframes.append((clip.clip_out - 1, 0))
+
+    # Because we created a SECOND SET of EditableProperties this only updates data structures (py and MLT)
+    # but not EditableProperties wrappers that are edited in GUI in "Compositor" panel.
+    keyframe_property.write_out_keyframes(keyframes)
+
+    # We need to return updated keyframes to update GUI in "Compositor" panel.
+    return keyframes
+    
 def _show_length_error_dialog():
     parent_window = gui.editor_window.window
     primary_txt = _("Clip too short!")
