@@ -18,28 +18,30 @@
     along with Flowblade Movie Editor.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-
-
 from gi.repository import Gtk
 import os
 from xml.dom import minidom
 from math import floor
 import mlt
 import time
-import md5
+import hashlib
 import re
 import shutil
 
 import appconsts
+import atomicfile
 import dialogs
 import dialogutils
 from editorstate import PLAYER
 from editorstate import PROJECT
 from editorstate import current_sequence
+import exportardour
 import gui
 import guiutils
 import renderconsumer
 import utils
+import userfolders
+
 
 REEL_NAME_HASH_8_NUMBER = 1
 REEL_NAME_FILE_NAME_START = 2
@@ -50,6 +52,7 @@ _screenshot_img = None
 _img_types = ["png", "bmp", "targa","tiff"]
 _img_extensions = ["png", "bmp", "tga","tif"]
 
+
 ####---------------MLT--------------####    
 def MELT_XML_export():
     dialogs.export_xml_dialog(_export_melt_xml_dialog_callback, PROJECT().name)
@@ -58,10 +61,13 @@ def _export_melt_xml_dialog_callback(dialog, response_id):
     if response_id == Gtk.ResponseType.ACCEPT:
         filenames = dialog.get_filenames()
         save_path = filenames[0]
-        #global _xml_render_monitor
-        _xml_render_player = renderconsumer.XMLRenderPlayer(save_path,
-                                                          _xml_render_done,
-                                                          None)
+
+        _xml_render_player = renderconsumer.XMLRenderPlayer(  save_path,
+                                                              _xml_render_done,
+                                                              None,
+                                                              PROJECT().c_seq,
+                                                              PROJECT(),
+                                                              PLAYER())
         _xml_render_player.start()
         
         dialog.destroy()
@@ -85,7 +91,10 @@ def _export_edl_dialog_callback(dialog, response_id):
         
         _xml_render_player = renderconsumer.XMLRenderPlayer(get_edl_temp_xml_path(),
                                                             _edl_xml_render_done,
-                                                            edl_path)
+                                                            edl_path,
+                                                            PROJECT().c_seq,
+                                                            PROJECT(),
+                                                            PLAYER())
         _xml_render_player.start()
 
         dialog.destroy()
@@ -96,13 +105,12 @@ def _edl_xml_render_done(data):
     edl_path  = data
     mlt_parse = MLTXMLToEDLParse(get_edl_temp_xml_path(), current_sequence())
     edl_contents = mlt_parse.create_edl()
-    f = open(edl_path, 'w')
-    f.write(edl_contents.encode('utf-8'))
-    f.close()
-
+    with atomicfile.AtomicFileWriter(edl_path, "w") as afw:
+        f = afw.get_file()
+        f.write(edl_contents)
 
 def get_edl_temp_xml_path():
-    return utils.get_hidden_user_dir_path() + "edl_temp_xml.xml"
+    return userfolders.get_cache_dir() + "edl_temp_xml.xml"
 
 
 class MLTXMLToEDLParse:
@@ -121,7 +129,7 @@ class MLTXMLToEDLParse:
     def get_project_profile(self):
         profile_dict = {}
         profile = self.xmldoc.getElementsByTagName("profile")
-        key_list = profile.item(0).attributes.keys()
+        key_list = list(profile.item(0).attributes.keys())
         for a in key_list:
             profile_dict[a] = profile.item(0).attributes[a].value
         return profile_dict
@@ -205,7 +213,7 @@ class MLTXMLToEDLParse:
             self.producers[producer_data["id"]] = producer_data
     
     def link_resources(self):
-        for producer_id, producer_data in self.producers.iteritems():
+        for producer_id, producer_data in self.producers.items():
 
             producer_resource = producer_data["resource"]
             reel_name = self.get_reel_name(producer_resource)
@@ -217,7 +225,7 @@ class MLTXMLToEDLParse:
                 existing_resource = self.reel_name_to_resource[reel_name]
 
                 if existing_resource != producer_resource:
-                    reel_name = md5.new(producer_resource).hexdigest()[:8]
+                    reel_name = hashlib.md5(producer_resource.encode('utf-8')).hexdigest()[:8]
                     
 
             self.resource_to_reel_name[producer_resource] = reel_name
@@ -225,7 +233,7 @@ class MLTXMLToEDLParse:
 
     def get_reel_name(self, resource):
         if self.reel_name_type == REEL_NAME_HASH_8_NUMBER:
-            return "{0:08d}".format(md5.new(resource).hexdigest())
+            return "{0:08d}".format(hashlib.md5(resource.encode('utf-8')).hexdigest())
         else:
             file_name = resource.split("/")[-1]
             file_name_no_ext = file_name.split(".")[0]
@@ -392,8 +400,8 @@ def _export_screenshot_dialog_callback(dialog, response_id, data):
     if response_id == Gtk.ResponseType.YES:
         vcodec = _img_types[file_type_combo.get_active()]
         ext = _img_extensions[file_type_combo.get_active()]
-        render_path = utils.get_hidden_screenshot_dir_path() + "screenshot_%01d." + ext
-        rendered_file_path = utils.get_hidden_screenshot_dir_path() + "screenshot_1." + ext 
+        render_path = userfolders.get_hidden_screenshot_dir_path() + "screenshot_%01d." + ext
+        rendered_file_path = userfolders.get_hidden_screenshot_dir_path() + "screenshot_1." + ext 
         out_file_path = out_folder.get_filename()+ "/" + file_name.get_text() + "." + ext
         dialog.destroy()
 
@@ -406,13 +414,10 @@ def _export_screenshot_dialog_callback(dialog, response_id, data):
     PLAYER().seek_frame(frame)
 
 def get_displayed_image_render_path():
-    return utils.get_hidden_screenshot_dir_path() + "screenshot_%01d.png"
+    return userfolders.get_hidden_screenshot_dir_path() + "screenshot_%01d.png"
 
 def get_displayed_image_path():
-    return utils.get_hidden_screenshot_dir_path() + "screenshot_1.png"
-
-def _screenshot_frame_changed(adjustment):
-    _update_displayed_image(int(adjustment.get_value()))
+    return userfolders.get_hidden_screenshot_dir_path() + "screenshot_1.png"
 
 def render_screen_shot(frame, render_path, vcodec):
     producer = current_sequence().tractor   
@@ -434,8 +439,8 @@ def render_screen_shot(frame, render_path, vcodec):
         time.sleep(0.05)
 
 def export_screenshot_dialog(callback, frame, parent_window, project_name):
-    cancel_str = _("Cancel").encode('utf-8')
-    ok_str = _("Export Image").encode('utf-8')
+    cancel_str = _("Cancel")
+    ok_str = _("Export Image")
     dialog = Gtk.Dialog(_("Export Frame Image"),
                         parent_window,
                         Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
@@ -494,6 +499,56 @@ def _file_type_changed(combo, label):
     label.set_text("." + _img_extensions[combo.get_active()])
 
 def purge_screenshots():
-    d = utils.get_hidden_screenshot_dir_path()
+    d = userfolders.get_hidden_screenshot_dir_path()
     for f in os.listdir(d):
         os.remove(os.path.join(d, f))
+
+
+
+####---------------Ardour Session--------------####
+def ardour_export():
+    print ("Ardour export...")
+    dialogs.export_ardour_session_folder_select(_ardour_export_dialog_callback)
+    
+    
+def _ardour_export_dialog_callback(dialog, response_id, session_folder):
+    if response_id != Gtk.ResponseType.ACCEPT:
+        dialog.destroy()
+        return
+        
+    folder_path = session_folder.get_filenames()[0]
+    if not (os.listdir(folder_path) == []):
+        dialog.destroy()
+        primary_txt = _("Selected folder contains files")
+        secondary_txt = _("When exporting audio to Ardour, the selected folder\nhas to be empty.")
+        dialogutils.info_message(primary_txt, secondary_txt, gui.editor_window.window)
+        return
+
+    # name = name_entry.get_text()
+    dialog.destroy()
+
+    xml_save_path = userfolders.get_cache_dir() + "ardour_export.xml"
+    
+    global _xml_render_player
+    _xml_render_player = renderconsumer.XMLRenderPlayer(  xml_save_path,
+                                                          _ardour_xml_render_done,
+                                                          None,
+                                                          PROJECT().c_seq,
+                                                          PROJECT(),
+                                                          PLAYER())
+
+    _xml_render_player.ardour_session_folder = folder_path
+    _xml_render_player.start()
+
+def _ardour_xml_render_done(data):
+    global _xml_render_player
+    
+    adour_session_folder = _xml_render_player.ardour_session_folder
+    temp_xml = _xml_render_player.file_name
+    
+    _xml_render_player = None
+    
+    exportardour.use_existing_basedir = True
+    exportardour.launch_export_ardour_session_from_flowblade(temp_xml, adour_session_folder)
+
+    print ("Ardour export done.")
