@@ -25,6 +25,7 @@ import appconsts
 import cairoarea
 import editorpersistance
 import gui
+import guiutils # Aug-2019 - SvdB - BB
 import respaths
 
 BUTTONS_GRAD_STOPS = [   (1, 1, 1, 1, 0.2),
@@ -35,7 +36,7 @@ BUTTONS_GRAD_STOPS = [   (1, 1, 1, 1, 0.2),
 
 BUTTONS_PRESSED_GRAD_STOPS = [(1, 0.7, 0.7, 0.7, 1),
                              (0, 0.5, 0.5, 0.5, 1)]
-                             
+
 LINE_GRAD_STOPS = [ (1, 0.66, 0.66, 0.66, 1),
                             (0.95, 0.7, 0.7, 0.7, 1),
                             (0.65, 0.3, 0.3, 0.3, 1),
@@ -46,15 +47,15 @@ BUTTON_NOT_SENSITIVE_GRAD_STOPS = [(1, 0.9, 0.9, 0.9, 0.7),
 
 CORNER_DIVIDER = 5
 
-MB_BUTTONS_WIDTH = 317
-MB_BUTTONS_HEIGHT = 30
-MB_BUTTON_HEIGHT = 22
-MB_BUTTON_WIDTH = 30
+# Aug-2019 - SvdB - BB
+MB_BUTTONS_WIDTH = [317,634]
+MB_BUTTONS_HEIGHT = [30,60]
+MB_BUTTON_HEIGHT = [22,44]
+MB_BUTTON_WIDTH = [30,60]
 MB_BUTTON_Y = 4
 MB_BUTTON_IMAGE_Y = 6
 
 GMIC_BUTTONS_WIDTH = 250
-NATRON_BUTTONS_WIDTH = 100
 
 M_PI = math.pi
 
@@ -70,8 +71,8 @@ class AbstractGlassButtons:
 
     def __init__(self, button_width, button_height, button_y, widget_width, widget_height):
         # Create widget and connect listeners
-        self.widget = cairoarea.CairoDrawableArea2( widget_width, 
-                                                    widget_height, 
+        self.widget = cairoarea.CairoDrawableArea2( widget_width,
+                                                    widget_height,
                                                     self._draw)
         self.widget.press_func = self._press_event
         self.widget.motion_notify_func = self._motion_notify_event
@@ -98,9 +99,9 @@ class AbstractGlassButtons:
             self.glass_style = True
         else:
             self.glass_style = False
-        
+
         self.no_decorations = False
-        
+
         # Dark theme comes with flat buttons
         self.dark_theme = False
         if editorpersistance.prefs.theme != appconsts.LIGHT_THEME:
@@ -115,7 +116,7 @@ class AbstractGlassButtons:
         radius = corner_radius / aspect
 
         self._draw_consts = (x, y, width, height, aspect, corner_radius, radius)
-    
+
     def set_sensitive(self, value):
         self.sensitive = []
         for i in self.icons:
@@ -133,16 +134,16 @@ class AbstractGlassButtons:
         cr.close_path ()
 
     def _press_event(self, event):
-        print "_press_event not impl"
+        print("_press_event not impl")
 
     def _motion_notify_event(self, x, y, state):
-        print "_motion_notify_event not impl"
+        print("_motion_notify_event not impl")
 
     def _release_event(self, event):
-        print "_release_event not impl"
+        print("_release_event not impl")
 
     def _draw(self, event, cr, allocation):
-        print "_draw not impl"
+        print("_draw not impl")
 
     def _get_hit_code(self, x, y):
         button_x = self.button_x
@@ -150,11 +151,11 @@ class AbstractGlassButtons:
             if ((x >= button_x) and (x <= button_x + self.button_width)
                 and (y >= self.button_y) and (y <= self.button_y + self.button_height)):
                     if self.sensitive[i] == True:
-                        return i 
+                        return i
             button_x += self.button_width
 
         return NO_HIT
-        
+
     def _draw_buttons(self, cr, w, h):
         # Width of buttons group
         buttons_width = self.button_width * len(self.icons)
@@ -165,22 +166,14 @@ class AbstractGlassButtons:
                 icon = self.icons[i]
                 cr.set_source_surface(icon, x + self.image_x[i], self.image_y[i])
                 cr.paint()
-                if self.sensitive[i] == False:
-                    cr.save()
-                    self._round_rect_path(cr)
-                    cr.set_source(grad)
-                    cr.clip()
-                    cr.rectangle(x, self.button_y, self.button_width, self.button_height)
-                    cr.fill()
-                    cr.restore()
                 x += self.button_width
-            
+
             return
 
         # Line width for all strokes
         cr.set_line_width(1.0)
 
-        # bg 
+        # bg
         self._set_button_draw_consts(self.button_x + 0.5, self.button_y + 0.5, buttons_width, self.button_height + 1.0)
         self._round_rect_path(cr)
         r, g, b, a  = gui.get_bg_color()
@@ -274,38 +267,71 @@ class AbstractGlassButtons:
                 cr.stroke()
             x += self.button_width
 
-        
+
 class PlayerButtons(AbstractGlassButtons):
 
     def __init__(self):
+        # Aug-2019 - SvdB - BB - Multiple changes - size_ind, size_adj, get_cairo_image
+        size_ind = 0
+        size_adj = 1
+        prefs = editorpersistance.prefs
+        if prefs.double_track_hights:
+           size_ind = 1
+           size_adj = 2
+        AbstractGlassButtons.__init__(self, MB_BUTTON_WIDTH[size_ind], MB_BUTTON_HEIGHT[size_ind], MB_BUTTON_Y, MB_BUTTONS_WIDTH[size_ind], MB_BUTTONS_HEIGHT[size_ind])
 
-        AbstractGlassButtons.__init__(self, MB_BUTTON_WIDTH, MB_BUTTON_HEIGHT, MB_BUTTON_Y, MB_BUTTONS_WIDTH, MB_BUTTONS_HEIGHT)
-
-        IMG_PATH = respaths.IMAGE_PATH
-        # Jul-2016 - SvdB - Modified to replace play/stop combo by single play/pause button, if option is set
-        play_pause_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "play_pause_s.png")
-        #
-        play_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "play_2_s.png")
-        stop_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "stop_s.png")
-        next_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "next_frame_s.png")
-        prev_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "prev_frame_s.png")
-        mark_in_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "mark_in_s.png")
-        mark_out_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "mark_out_s.png")
-        marks_clear_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "marks_clear_s.png") 
-        to_mark_in_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "to_mark_in_s.png")        
-        to_mark_out_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "to_mark_out_s.png") 
+        play_pause_icon = guiutils.get_cairo_image("play_pause_s")
+        play_icon = guiutils.get_cairo_image("play_2_s")
+        stop_icon = guiutils.get_cairo_image("stop_s")
+        next_icon = guiutils.get_cairo_image("next_frame_s")
+        prev_icon = guiutils.get_cairo_image("prev_frame_s")
+            # ------------------------------timeline_start_end_button
+        start_icon = guiutils.get_cairo_image("to_start") #  go to start
+        end_icon = guiutils.get_cairo_image("to_end") #  go to end
+            # ------------------------------timeline_start_end_button
+        mark_in_icon = guiutils.get_cairo_image("mark_in_s")
+        mark_out_icon = guiutils.get_cairo_image("mark_out_s")
+        marks_clear_icon = guiutils.get_cairo_image("marks_clear_s")
+        to_mark_in_icon = guiutils.get_cairo_image("to_mark_in_s")
+        to_mark_out_icon = guiutils.get_cairo_image("to_mark_out_s")
 
         # Jul-2016 - SvdB - For play/pause button
         if (editorpersistance.prefs.play_pause == True):
-            self.icons = [prev_icon, next_icon, play_pause_icon,
-                          mark_in_icon, mark_out_icon, 
+            # ------------------------------timeline_start_end_button
+            if (editorpersistance.prefs.timeline_start_end == True):
+                self.icons = [start_icon, end_icon, prev_icon, next_icon, play_pause_icon,
+                          mark_in_icon, mark_out_icon,
                           marks_clear_icon, to_mark_in_icon, to_mark_out_icon]
-            self.image_x = [5, 7, 5, 3, 11, 2, 7, 6]
+                #  go to start end add 5*size_adj, 5*size_adj,
+                self.image_x = [5*size_adj, 5*size_adj, 5*size_adj, 7*size_adj, 5*size_adj, 3*size_adj, 11*size_adj, 2*size_adj, 7*size_adj, 6*size_adj]
+            else:
+                self.icons = [prev_icon, next_icon, play_pause_icon,
+                          mark_in_icon, mark_out_icon,
+                          marks_clear_icon, to_mark_in_icon, to_mark_out_icon]
+                self.image_x = [ 5*size_adj, 7*size_adj, 5*size_adj, 3*size_adj, 11*size_adj, 2*size_adj, 7*size_adj, 6*size_adj]
         else:
-            self.icons = [prev_icon, next_icon, play_icon, stop_icon, 
-                          mark_in_icon, mark_out_icon, 
-                          marks_clear_icon, to_mark_in_icon, to_mark_out_icon]
-            self.image_x = [5, 7, 10, 10, 3, 11, 2, 7, 6]
+            #  go to start end
+            if (editorpersistance.prefs.timeline_start_end == True):
+                self.icons = [start_icon, end_icon, prev_icon, next_icon, play_icon, stop_icon,
+                              mark_in_icon, mark_out_icon,
+                              marks_clear_icon, to_mark_in_icon, to_mark_out_icon]
+                #  go to start end add 5*size_adj, 5*size_adj,
+                self.image_x = [5*size_adj, 5*size_adj, 5*size_adj, 7*size_adj, 5*size_adj, 10*size_adj, 3*size_adj, 11*size_adj, 2*size_adj, 7*size_adj, 6*size_adj]
+            else:
+                self.icons = [prev_icon, next_icon, play_icon, stop_icon,
+                              mark_in_icon, mark_out_icon,
+                              marks_clear_icon, to_mark_in_icon, to_mark_out_icon]
+                self.image_x = [5*size_adj, 7*size_adj, 20*size_adj, 10*size_adj, 3*size_adj, 11*size_adj, 2*size_adj, 7*size_adj, 6*size_adj]
+            # ------------------------------End of timeline_start_end_button
+#            self.icons = [prev_icon, next_icon, play_pause_icon,
+#                          mark_in_icon, mark_out_icon,
+#                          marks_clear_icon, to_mark_in_icon, to_mark_out_icon]
+#            self.image_x = [5*size_adj, 7*size_adj, 5*size_adj, 3*size_adj, 11*size_adj, 2*size_adj, 7*size_adj, 6*size_adj]
+#        else:
+#            self.icons = [prev_icon, next_icon, play_icon, stop_icon,
+#                          mark_in_icon, mark_out_icon,
+#                          marks_clear_icon, to_mark_in_icon, to_mark_out_icon]
+#            self.image_x = [5*size_adj, 7*size_adj, 10*size_adj, 10*size_adj, 3*size_adj, 11*size_adj, 2*size_adj, 7*size_adj, 6*size_adj]
 
         for i in range(0, len(self.icons)):
             self.image_y.append(MB_BUTTON_IMAGE_Y)
@@ -313,7 +339,7 @@ class PlayerButtons(AbstractGlassButtons):
         self.pressed_callback_funcs = None # set using set_callbacks()
 
         self.set_sensitive(True)
-        
+
         focus_groups[DEFAULT_FOCUS_GROUP].append(self.widget)
 
     def set_trim_sensitive_pattern(self):
@@ -356,7 +382,7 @@ class PlayerButtons(AbstractGlassButtons):
         self.widget.queue_draw()
 
     def set_callbacks(self, pressed_callback_funcs):
-        self.pressed_callback_funcs = pressed_callback_funcs 
+        self.pressed_callback_funcs = pressed_callback_funcs
 
     # ---------------------------------------------------------------- painting
     def _draw(self, event, cr, allocation):
@@ -375,18 +401,18 @@ class GmicButtons(AbstractGlassButtons):
 
     def __init__(self):
 
-        AbstractGlassButtons.__init__(self, MB_BUTTON_WIDTH, MB_BUTTON_HEIGHT, MB_BUTTON_Y, GMIC_BUTTONS_WIDTH, MB_BUTTONS_HEIGHT)
+        AbstractGlassButtons.__init__(self, MB_BUTTON_WIDTH[0], MB_BUTTON_HEIGHT[0], MB_BUTTON_Y, GMIC_BUTTONS_WIDTH, MB_BUTTONS_HEIGHT[0])
 
         IMG_PATH = respaths.IMAGE_PATH
         next_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "next_frame_s.png")
         prev_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "prev_frame_s.png")
         mark_in_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "mark_in_s.png")
         mark_out_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "mark_out_s.png")
-        marks_clear_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "marks_clear_s.png") 
-        to_mark_in_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "to_mark_in_s.png")        
-        to_mark_out_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "to_mark_out_s.png") 
+        marks_clear_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "marks_clear_s.png")
+        to_mark_in_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "to_mark_in_s.png")
+        to_mark_out_icon = cairo.ImageSurface.create_from_png(IMG_PATH + "to_mark_out_s.png")
 
-        self.icons = [prev_icon, next_icon, mark_in_icon, mark_out_icon, 
+        self.icons = [prev_icon, next_icon, mark_in_icon, mark_out_icon,
                       marks_clear_icon, to_mark_in_icon, to_mark_out_icon]
         self.image_x = [8, 10, 6, 14, 5, 10, 9]
 
@@ -396,7 +422,7 @@ class GmicButtons(AbstractGlassButtons):
         self.pressed_callback_funcs = None # set using set_callbacks()
 
         self.set_sensitive(True)
-        
+
         focus_groups[DEFAULT_FOCUS_GROUP].append(self.widget)
 
 
@@ -432,7 +458,7 @@ class GmicButtons(AbstractGlassButtons):
         self.widget.queue_draw()
 
     def set_callbacks(self, pressed_callback_funcs):
-        self.pressed_callback_funcs = pressed_callback_funcs 
+        self.pressed_callback_funcs = pressed_callback_funcs
 
     # ---------------------------------------------------------------- painting
     def _draw(self, event, cr, allocation):
@@ -491,7 +517,7 @@ class GlassButtonsGroup(AbstractGlassButtons):
 
 
 
-class GlassButtonsToggleGroup(GlassButtonsGroup):    
+class GlassButtonsToggleGroup(GlassButtonsGroup):
     def set_pressed_button(self, pressed_button_index, fire_clicked_cb=False):
         self.pressed_button = pressed_button_index
         if fire_clicked_cb == True:
@@ -520,36 +546,36 @@ class GlassButtonsToggleGroup(GlassButtonsGroup):
 
 
 class TooltipRunner:
-    
+
     def __init__(self, glassbuttons, tooltips):
         self.glassbuttons = glassbuttons
         self.tooltips = tooltips
-        
+
         self.glassbuttons.widget.set_has_tooltip(True)
         self.glassbuttons.widget.connect("query-tooltip", self.tooltip_query)
         self.glassbuttons.tooltip_runner = self
-        
+
         self.last_hit_code = NO_HIT
-        
+
     def tooltip_query(self, widget, x, y, keyboard_tooltip, tooltip):
         hit_code = self.glassbuttons._get_hit_code(x, y)
         if hit_code == NO_HIT:
             return False
-        
-        # This is needed to get better position for tooltips when tooltips have significantly different amount of text displayed 
+
+        # This is needed to get better position for tooltips when tooltips have significantly different amount of text displayed
         if hit_code != self.last_hit_code:
             self.last_hit_code = hit_code
             self.glassbuttons.widget.trigger_tooltip_query()
             return False
-        
+
         tooltip.set_markup(self.tooltips[hit_code])
         return True
-        
+
 
 def focus_group_has_focus(focus_group):
     group = focus_groups[focus_group]
     for widget in group:
         if widget.has_focus():
             return True
-    
+
     return False
