@@ -29,6 +29,8 @@ from gi.repository import Gtk, Gdk
 from gi.repository import GdkPixbuf
 
 import appconsts
+import cairo # Aug-2019 - SvdB - BB
+import editorpersistance # Aug-2019 - SvdB - BB
 import respaths
 import translations
 
@@ -127,14 +129,66 @@ def get_two_row_box(widget1, widget2):
     box.pack_start(top, False, False, 4)
     box.pack_start(widget2, False, False, 0)
     return box
+
+def get_right_expand_box(widget1, widget2, center_pad=False):
+    hbox = Gtk.HBox()
+    hbox.pack_start(widget1, False, True, 0)
+    if center_pad:
+        hbox.pack_start(pad_label(4,4), False, True, 0)
+    hbox.pack_start(widget2, True, True, 0)
+    return hbox
+
+# Aug-2019 - SvdB - BB
+def get_image_name(img_name, suffix = ".png", double_height = False):
+    button_size_text = ""
+    if double_height:
+       button_size_text = "@2"    
+    img_name = img_name+button_size_text+suffix
+    return img_name
+
+# Aug-2019 - SvdB - BB
+def get_image(img_name, suffix = ".png", force = None):
+    # Use parameter force as True or False to force the track height no matter what the preferences setting
+    if force == None:
+        force = editorpersistance.prefs.double_track_hights
+    if force:
+        new_name = img_name + "@2"
+    else:
+        new_name = img_name
+    try:
+        img = Gtk.Image.new_from_file(respaths.IMAGE_PATH + new_name + suffix)
+    except:
+        img = Gtk.Image.new_from_file(respaths.IMAGE_PATH + img_name + suffix)
+    return img
     
+
+# Aug-2019 - SvdB - BB
+def get_cairo_image(img_name, suffix = ".png", force = None):
+    # Apr-2020 - SvdB - Make it sturdier in case a @2 image is missing. Just display the original image.
+    # Use parameter force as True or False to force the track height no matter what the preferences setting
+    if force == None:
+        force = editorpersistance.prefs.double_track_hights
+    if force:
+        new_name = img_name + "@2"
+    else:
+        new_name = img_name
+    try:
+        img = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + new_name + suffix)
+    except:
+        img = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + img_name + suffix)
+    return img
+
+# Aug-2019 - SvdB - BB
 def get_image_button(img_file_name, width, height):
     button = Gtk.Button()
-    icon = Gtk.Image.new_from_file(respaths.IMAGE_PATH + img_file_name)        
+    icon = get_image(img_file_name)        
+    size_adj = 1
+    if editorpersistance.prefs.double_track_hights:
+        size_adj = 2
     button_box = Gtk.HBox()
     button_box.pack_start(icon, False, False, 0)
     button.add(button_box)
-    button.set_size_request(width, height)
+    button.set_size_request(width*size_adj, height*size_adj)
     return button
     
 def get_pad_label(w, h):
@@ -199,7 +253,7 @@ def get_slider_row_and_spin_widget(editable_property, listener, slider_name=None
     
     editable_property.value_changed_ID = adjustment.connect("value-changed", listener) # saving ID to make it available for disconnect
                                                                                        # This also needs to be available after adjustment is set to not lose exiting value for build dummy value 
-        
+    
     return (get_two_column_editor_row(name, hbox), hslider, spin)
     
 def get_non_property_slider_row(lower, upper, step, value=0, listener=None):
@@ -261,7 +315,9 @@ def get_named_frame(name, widget, left_padding=12, right_padding=6, right_out_pa
         label_box.pack_start(Gtk.Label(), True, True, 0)
         if tooltip_txt != None:        
             label.set_tooltip_markup(tooltip_txt)
-            
+    else:
+        label = Gtk.Label()
+
     alignment = set_margins(widget, right_padding, 0, left_padding, 0)
 
     frame = Gtk.VBox()
@@ -269,6 +325,8 @@ def get_named_frame(name, widget, left_padding=12, right_padding=6, right_out_pa
         frame.pack_start(label_box, False, False, 0)
     frame.pack_start(alignment, True, True, 0)
     
+    frame.name_label = label
+    
     out_align = set_margins(frame, 4, 4, 0, right_out_padding)
     
     return out_align
@@ -313,6 +371,25 @@ def get_menu_item(text, callback, data, sensitive=True):
     item.set_sensitive(sensitive)
     return item
 
+
+def get_image_menu_item(text, image_name, callback, tooltip_markup=None):
+    img = get_image(image_name)
+    text_label = Gtk.Label(text)
+    
+    hbox = Gtk.HBox()
+    hbox.pack_start(pad_label(4, 4), False, False, 0)
+    hbox.pack_start(img, False, False, 0)
+    hbox.pack_start(pad_label(4, 4), False, False, 0)
+    hbox.pack_start(text_label, False, False, 0)
+    hbox.show_all()
+    item = Gtk.MenuItem()
+    item.add(hbox)
+    if tooltip_markup != None:
+        item.set_tooltip_markup(tooltip_markup)
+    item.show()
+
+    return item
+    
 def get_radio_menu_items_group(menu, labels, msgs, callback, active_index):
     first_item = Gtk.RadioMenuItem()
     first_item.set_label(labels[0])
