@@ -24,6 +24,7 @@ Module handles keyevents.
 
 from gi.repository import Gdk
 
+import appconsts
 import audiowaveform
 import clipeffectseditor
 import compositeeditor
@@ -41,11 +42,14 @@ import medialog
 import menuactions
 import modesetting
 import monitorevent
+import movemodes
 import multitrimmode
 # Apr-2017 - SvdB
 import shortcuts
 import re
+import rotomask
 import tlineaction
+import tlinerender
 import tlinewidgets
 import trimmodes
 import updater
@@ -83,7 +87,7 @@ def key_down(widget, event):
         # Stop widget focus from travelling if arrow key pressed
         gui.editor_window.window.emit_stop_by_name("key_press_event")
         return True
-    
+
     # If timeline widgets are in focus timeline keyevents are available
     if _timeline_has_focus():
         was_handled = _handle_tline_key_event(event)
@@ -100,25 +104,12 @@ def key_down(widget, event):
         # Stop event handling here
         return True
 
+    was_handled = _handle_configurable_global_events(event)
+    if was_handled:
+        return True
+        
     # Pressing timeline button obivously leaves user expecting
     # to have focus in timeline
-    """
-    TODO: this needs something
-    if gui.sequence_editor_b.has_focus():
-        _handle_tline_key_event(event)
-        # Stop event handling here
-        return True
-    """
-    
-    # Clip button or posbar focus with clip displayed leaves playback keyshortcuts available
-    """
-    if (gui.clip_editor_b.has_focus()
-        TODO: this needs something
-        or (gui.pos_bar.widget.is_focus() and (not timeline_visible()))):
-        _handle_clip_key_event(event)
-        # Stop event handling here
-        return True
-    """
     if gui.monitor_switch.widget.has_focus() and timeline_visible():
         _handle_tline_key_event(event)
         return True
@@ -162,10 +153,10 @@ def key_down(widget, event):
         menuactions.toggle_fullscreen()
         return True
 
-    #debug
+    #debug.test help 
     if event.keyval == Gdk.KEY_F12:
         if (event.get_state() & Gdk.ModifierType.CONTROL_MASK):
-            tlineaction.ripple_delete_button_pressed()
+            rotomask.show_rotomask()
         return True
 
     # Key event was not handled here.
@@ -188,14 +179,15 @@ def _handle_tline_key_event(event):
     Returns True for handled key presses to stop those
     keyevents from going forward.
     """
-
     tool_was_selected = workflow.tline_tool_keyboard_selected(event)
     if tool_was_selected == True:
         return True
     
+
     action = _get_shortcut_action(event)
     prefs = editorpersistance.prefs
 
+
     if action == 'mark_in':
         monitorevent.mark_in_pressed()
         return True
@@ -212,6 +204,9 @@ def _handle_tline_key_event(event):
     if action == 'to_mark_out':
         monitorevent.to_mark_out_pressed()
         return True
+    if action == 'clear_io_marks':
+        monitorevent.marks_clear_pressed()
+        return True
     if action == 'play_pause':
         if PLAYER().is_playing():
             monitorevent.stop_pressed()
@@ -252,7 +247,20 @@ def _handle_tline_key_event(event):
             trimmodes.enter_pressed()
             return True
 
-
+    if editorstate.EDIT_MODE() == editorstate.OVERWRITE_MOVE:
+        if action == 'nudge_back':
+            movemodes.nudge_selection(-1)
+            return True
+        elif action == 'nudge_forward':
+            movemodes.nudge_selection(1)
+            return True
+        elif action == 'nudge_back_10':
+            movemodes.nudge_selection(-10)
+            return True
+        elif action == 'nudge_forward_10':
+            movemodes.nudge_selection(10)
+            return True
+    
     if editorstate.EDIT_MODE() == editorstate.MULTI_TRIM:
         multitrimmode.enter_pressed()
 
@@ -302,6 +310,9 @@ def _handle_tline_key_event(event):
         if action == '3_point_overwrite':
             tlineaction.three_point_overwrite_pressed()
             return True
+        if action == 'overwrite_range':
+            tlineaction.range_overwrite_pressed()
+            return True
         if action == 'insert':
             if not (event.get_state() & Gdk.ModifierType.CONTROL_MASK):
                 tlineaction.insert_button_pressed()
@@ -309,6 +320,9 @@ def _handle_tline_key_event(event):
         if action == 'append':
             tlineaction.append_button_pressed()
             return True
+        if action == 'append_from_bin':
+            projectaction.append_selected_media_clips_into_timeline()
+            return True
         if action == 'slower':
             monitorevent.j_pressed()
             return True
@@ -332,6 +346,9 @@ def _handle_tline_key_event(event):
                 # so max one one these will actually delete something
                 tlineaction.splice_out_button_pressed()
                 compositormodes.delete_current_selection()
+        if action == 'lift':
+            tlineaction.lift_button_pressed()
+            return True
         if action == 'to_start':
             if PLAYER().is_playing():
                 monitorevent.stop_pressed()
@@ -376,6 +393,9 @@ def _handle_extended_monitor_focus_events(event):
     if action == '3_point_overwrite':
         tlineaction.three_point_overwrite_pressed()
         return True
+    if action == 'overwrite_range':
+        tlineaction.range_overwrite_pressed()
+        return True
     if action == 'insert':
         tlineaction.insert_button_pressed()
         return True
@@ -397,7 +417,10 @@ def _handle_extended_monitor_focus_events(event):
     if action == 'switch_monitor':
         updater.switch_monitor_display()
         return True
-    
+    if action == 'append_from_bin':
+        projectaction.append_selected_media_clips_into_timeline()
+        return True
+
     tool_was_selected = workflow.tline_tool_keyboard_selected(event)
     if tool_was_selected == True:
         return True
@@ -408,6 +431,7 @@ def _handle_extended_monitor_focus_events(event):
 def _get_shortcut_action(event):
     # Get the name of the key pressed
     key_name = Gdk.keyval_name(event.keyval).lower()
+
     # Check if this key is in the dictionary.
     state = event.get_state()
     # Now we have a key and a key state we need to check if it is a shortcut.
@@ -447,6 +471,14 @@ def _get_shortcut_action(event):
     # We didn't find an action, so return nothing 
     return 'None'
 
+def _handle_configurable_global_events(event):
+    action = _get_shortcut_action(event)
+    if action == 'open_next':
+        projectaction.open_next_media_item_in_monitor()
+        return True
+
+    return False
+    
 def _handle_clip_key_event(event):
     # Key bindings for MOVE MODES
     if editorstate.current_is_move_mode():
@@ -512,6 +544,9 @@ def _handle_clip_key_event(event):
         if action == 'to_mark_out':
             monitorevent.to_mark_out_pressed()
             return True
+        if action == 'clear_io_marks':
+            monitorevent.marks_clear_pressed()
+            return True
 
 def _handle_delete():
     # Delete media file
@@ -543,6 +578,11 @@ def _handle_delete():
         medialog.delete_selected()
         return True
 
+    # Delete tline render segment
+    if gui.tline_render_strip.widget.has_focus() == True:
+        tlinerender.get_renderer().delete_selected_segment()
+        return True
+    
     focus_editor = _get_focus_keyframe_editor(compositeeditor.keyframe_editor_widgets)
     if focus_editor != None:
         focus_editor.delete_pressed()
@@ -584,13 +624,27 @@ def _handle_effects_editor_keys(event):
     action = _get_shortcut_action(event)
     focus_editor = _get_focus_keyframe_editor(clipeffectseditor.keyframe_editor_widgets)
     if focus_editor != None:
-      if action == 'play_pause':
+        if action == 'play_pause':
             if PLAYER().is_playing():
                 monitorevent.stop_pressed()
             else:
                 monitorevent.play_pressed()
             return True
-
+        if action == 'prev_frame' or action == 'next_frame':
+            prefs = editorpersistance.prefs
+            if action == 'prev_frame':
+                seek_amount = -1
+            else:
+                seek_amount = 1
+            if (event.get_state() & Gdk.ModifierType.SHIFT_MASK):
+                seek_amount = seek_amount * prefs.ffwd_rev_shift
+            if (event.get_state() & Gdk.ModifierType.CONTROL_MASK):
+                seek_amount = seek_amount * prefs.ffwd_rev_ctrl
+            if (event.get_state() & Gdk.ModifierType.LOCK_MASK):
+                seek_amount = seek_amount * prefs.ffwd_rev_caps
+            PLAYER().seek_delta(seek_amount)
+            return True
+        
     return False
 
 def _get_focus_keyframe_editor(keyframe_editor_widgets):
@@ -610,3 +664,41 @@ def _move_to_end():
     updater.repaint_tline()
     updater.update_tline_scrollbar()
 
+# ----------------------------------------------------------------------- COPY PASTE ACTION FORWARDING
+def copy_action():
+    if _timeline_has_focus() == False:
+        filter_kf_editor = _get_focus_keyframe_editor(clipeffectseditor.keyframe_editor_widgets)
+        geom_kf_editor = _get_focus_keyframe_editor(compositeeditor.keyframe_editor_widgets)
+        if filter_kf_editor != None:
+            value = filter_kf_editor.get_copy_kf_value()
+            save_data = (appconsts.COPY_PASTE_KEYFRAME_EDITOR_KF_DATA, (value, filter_kf_editor))
+            editorstate.set_copy_paste_objects(save_data) 
+        elif geom_kf_editor != None:
+            value = geom_kf_editor.get_copy_kf_value() 
+            save_data = (appconsts.COPY_PASTE_GEOMETRY_EDITOR_KF_DATA, (value, geom_kf_editor))
+            editorstate.set_copy_paste_objects(save_data) 
+        else:
+            # Try to extract text to clipboard because user pressed CTRL + C
+            copy_source = gui.editor_window.window.get_focus()
+            try:
+                copy_source.copy_clipboard()
+            except:# selected widget was not a Gtk.Editable that can provide text to clipboard
+                pass
+    else:
+        tlineaction.do_timeline_objects_copy()
+
+def paste_action():
+    if _timeline_has_focus() == False:
+        copy_paste_object = editorstate.get_copy_paste_objects()
+        if copy_paste_object == None:
+            return
+        data_type, paste_data = editorstate.get_copy_paste_objects()
+        if data_type == appconsts.COPY_PASTE_KEYFRAME_EDITOR_KF_DATA:
+            value, kf_editor = paste_data
+            kf_editor.paste_kf_value(value)
+        elif data_type == appconsts.COPY_PASTE_GEOMETRY_EDITOR_KF_DATA:
+            value, geom_editor = paste_data
+            geom_editor.paste_kf_value(value)
+    else:
+        tlineaction.do_timeline_objects_paste()
+
