@@ -52,6 +52,7 @@ import propertyparse
 import respaths
 import renderconsumer
 import translations
+import userfolders
 import utils
 
 linker_window = None
@@ -62,8 +63,8 @@ media_assets = []
 NO_PROJECT_AT_LAUNCH = "##&&noproject&&##"
 
 def display_linker(filename=NO_PROJECT_AT_LAUNCH):
-    print "Launching Media Re-linker"
-    FLOG = open(utils.get_hidden_user_dir_path() + "log_media_relinker", 'w')
+    print("Launching Media Relinker")
+    FLOG = open(userfolders.get_cache_dir() + "log_media_relinker", 'w')
     subprocess.Popen([sys.executable, respaths.LAUNCH_DIR + "flowblademedialinker", filename], stdin=FLOG, stdout=FLOG, stderr=FLOG)
 
 
@@ -380,14 +381,14 @@ def _update_media_assets():
     asset_paths = {}
             
     # Media file media assets
-    for media_file_id, media_file in target_project.media_files.iteritems():
+    for media_file_id, media_file in target_project.media_files.items():
         if isinstance(media_file, patternproducer.AbstractBinClip):
             continue
         try:
             new_assets.append(MediaAsset(media_file.path, media_file.type))
             asset_paths[media_file.path] = media_file.path
         except:
-            print "failed loading:", media_file
+            print("failed loading:", media_file)
             
     for seq in target_project.sequences:
         # Clip media assets
@@ -434,7 +435,7 @@ def _set_button_pressed():
 
 def _set_relink_path(media_asset):
     file_name = os.path.basename(media_asset.orig_path)
-    dialogs.media_file_dialog(_("Select Media File To Relink To") + " " + file_name.decode('utf-8'), 
+    dialogs.media_file_dialog(_("Select Media File To Relink To") + " " + file_name, 
                                 _select_relink_path_dialog_callback, False, 
                                 media_asset, linker_window, last_media_dir)
 
@@ -537,7 +538,7 @@ def _relink_project_media_paths():
             relinked_paths[media_asset.orig_path] = media_asset.relink_path
             
     # Relink media file media assets
-    for media_file_id, media_file in target_project.media_files.iteritems():
+    for media_file_id, media_file in target_project.media_files.items():
         if isinstance(media_file, patternproducer.AbstractBinClip):
             continue
         if media_file.path in relinked_paths:
@@ -568,13 +569,16 @@ def _relink_project_media_paths():
 # ----------------------------------------------------------- main
 def main(root_path, filename):
     gtk_version = "%s.%s.%s" % (Gtk.get_major_version(), Gtk.get_minor_version(), Gtk.get_micro_version())
-    print "GTK+ version:", gtk_version
+    print("GTK+ version:", gtk_version)
     editorstate.gtk_version = gtk_version
     try:
         editorstate.mlt_version = mlt.LIBMLT_VERSION
     except:
         editorstate.mlt_version = "0.0.99" # magic string for "not found"
 
+    # Create user folders if needed and determine if we are using xdg or dotfile userf folders.
+    userfolders.init()
+
     # Set paths.
     respaths.set_paths(root_path)
 
