@@ -23,7 +23,6 @@ This module handles the less central actions inited by user from menu.
 """
 
 
-
 from gi.repository import Gtk, Gdk
 
 import threading
@@ -38,7 +37,6 @@ from editorstate import PROJECT
 from editorstate import current_sequence
 import editorstate
 import gui
-import jackaudio
 import projectdata
 import patternproducer
 import profilesmanager
@@ -61,7 +59,7 @@ class RecreateIconsThread(threading.Thread):
 
         no_icon_path = respaths.IMAGE_PATH + projectdata.FALLBACK_THUMB
         loaded = 0
-        for key in PROJECT().media_files.iterkeys():
+        for key in PROJECT().media_files.keys():
             media_file = PROJECT().media_files[key]
             Gdk.threads_enter()
             recreate_progress_window.info.set_text(media_file.name)
@@ -117,7 +115,7 @@ def environment():
 def quick_reference():
     try:
         url = "file://" + respaths.HELP_DOC
-        print url 
+        print(url) 
         #webbrowser.open('http://code.google.com/p/flowblade/wiki/FlowbladeReference')
         webbrowser.open(url)
     except:
@@ -151,13 +149,8 @@ def _watermark_remove_callback(button, widgets):
     file_path_value_label.set_text(_("Not Set"))
     current_sequence().remove_watermark()
       
-def jack_output_managing():
-    dialog = jackaudio.JackAudioManagerDialog()
-    #PLAYER().jack_output_on()
-
-
 def toggle_fullscreen():
-    print "toggle_fullscreen"
+    print("toggle_fullscreen")
     if editorstate.fullscreen == False:
        gui.editor_window.window.fullscreen()
        editorstate.fullscreen = True
