@@ -27,6 +27,7 @@ import cairo
 from gi.repository import Gtk, Gdk
 
 import appconsts
+import editorpersistance # Aug-2019 - SvdB - BB
 import gui
 import guicomponents
 import guiutils
@@ -46,22 +47,28 @@ MEDIA_PANEL_DEFAULT_ROWS = 2
 
 
 def get_media_files_panel(media_list_view, add_cb, del_cb, col_changed_cb, hamburger_launch_pressed, filtering_cb):   
+    # Aug-2019 - SvdB - BB
+    size_adj = 1
+    prefs = editorpersistance.prefs
+    if prefs.double_track_hights:
+        size_adj = 2
     hamburger_launcher = guicomponents.HamburgerPressLaunch(hamburger_launch_pressed)
     guiutils.set_margins(hamburger_launcher.widget, 2, 0, 4, 12)
 
-    columns_img = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "columns.png")
-    columns_launcher = guicomponents.PressLaunch(col_changed_cb, columns_img, w=22, h=22)
+    columns_img = guiutils.get_cairo_image("columns")
+    columns_launcher = guicomponents.PressLaunch(col_changed_cb, columns_img, w=22*size_adj, h=22*size_adj)
     columns_launcher.surface_y = 6
     columns_launcher.widget.set_tooltip_text(_("Number of Media File columns."))
     
-    all_pixbuf = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "show_all_files.png")
-    audio_pixbuf = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "show_audio_files.png")
-    graphics_pixbuf = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "show_graphics_files.png")
-    video_pixbuf = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "show_video_files.png")
-    imgseq_pixbuf = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "show_imgseq_files.png")
-    pattern_pixbuf = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "show_pattern_producers.png")
+    all_pixbuf = guiutils.get_cairo_image("show_all_files")
+    audio_pixbuf = guiutils.get_cairo_image("show_audio_files")
+    graphics_pixbuf = guiutils.get_cairo_image("show_graphics_files")
+    video_pixbuf = guiutils.get_cairo_image("show_video_files")
+    imgseq_pixbuf = guiutils.get_cairo_image("show_imgseq_files")
+    pattern_pixbuf = guiutils.get_cairo_image("show_pattern_producers")
+    unused_pixbuf = guiutils.get_cairo_image("show_unused_files")
 
-    files_filter_launcher = guicomponents.ImageMenuLaunch(filtering_cb, [all_pixbuf, video_pixbuf, audio_pixbuf, graphics_pixbuf, imgseq_pixbuf, pattern_pixbuf], 24, 22)
+    files_filter_launcher = guicomponents.ImageMenuLaunch(filtering_cb, [all_pixbuf, video_pixbuf, audio_pixbuf, graphics_pixbuf, imgseq_pixbuf, pattern_pixbuf, unused_pixbuf], 24*size_adj, 22*size_adj)
     files_filter_launcher.surface_x  = 3
     files_filter_launcher.surface_y  = 4
     files_filter_launcher.widget.set_tooltip_text(_("Visible Media File types."))
@@ -113,62 +120,9 @@ def get_sequences_panel(sequence_list_view, edit_seq_cb, add_seq_cb, del_seq_cb)
 
     return get_named_frame(_("Sequences"), panel, 0, 6, 4, _("A <b>Sequence</b> is the full contents of the timeline creating a program, a movie."))
 
-def get_thumbnail_select_panel(current_folder_path):    
-    texts_panel = get_two_text_panel(_("Select folder for new thumbnails."), 
-                                     _("Old thumbnails in this or other projects will") + 
-                                     _(" still be available,\nthis only affects thumnails that are created for new media.\n") + 
-                                     _("\nSetting your home folder as thumbnails folder is not allowed."))
-
-    out_folder = Gtk.FileChooserButton("Select Folder")
-    out_folder.set_action(Gtk.FileChooserAction.SELECT_FOLDER)
-    if current_folder_path != None:
-        out_folder.set_current_folder(current_folder_path)
-    
-    out_folder_align = guiutils.set_margins(out_folder, 12, 24, 12, 12)
-
-    panel = Gtk.VBox()
-    panel.pack_start(texts_panel, False, False, 0)
-    panel.pack_start(out_folder_align, False, False, 0)
-    
-    return (panel, out_folder)
-
-def get_render_folder_select_panel(current_folder_path):    
-    texts_panel = get_two_text_panel(_("Select folder for rendered clips."), 
-                                     _("Old rendered clips in this or other projects will") + 
-                                     _(" still be available,\nthis only affects rendered files that are created from now on.\n") + 
-                                     _("\nSetting your home folder as folder for rendered clips is not allowed."))
-        
-    out_folder = Gtk.FileChooserButton("Select Folder")
-    out_folder.set_action(Gtk.FileChooserAction.SELECT_FOLDER)
-    if current_folder_path != None:
-        out_folder.set_current_folder(current_folder_path)
-
-    out_folder_align = guiutils.set_margins(out_folder, 12, 24, 12, 12)
-    
-    panel = Gtk.VBox()
-    panel.pack_start(texts_panel, False, False, 0)
-    panel.pack_start(out_folder_align, False, False, 0)
-    
-    return (panel, out_folder)
-
 def _set_sensive_widgets(sensitive, list):
     for widget in list:
         widget.set_sensitive(sensitive)
-"""
-def get_motion_render_progress_panel(file_name, progress_bar):
-    status_box = Gtk.HBox(False, 2)
-    status_box.pack_start(Gtk.Label(label=file_name),False, False, 0)
-    status_box.pack_start(Gtk.Label(), True, True, 0)
-
-    progress_vbox = Gtk.VBox(False, 2)
-    progress_vbox.pack_start(status_box, False, False, 0)
-    progress_vbox.pack_start(guiutils.get_pad_label(10, 10), False, False, 0)
-    progress_vbox.pack_start(progress_bar, False, False, 0)
-    print "ee"
-    alignment = guiutils.set_margins(progress_vbox, 12, 12, 12, 12)
-
-    return alignment
-"""
 
 def get_named_frame(name, widget, left_padding=12, right_padding=6, right_out_padding=4, tooltip_txt=None):
     """
@@ -306,7 +260,7 @@ def get_transition_panel(trans_data):
                                  type_combo_box)
 
     wipe_luma_combo_box = Gtk.ComboBoxText()
-    keys = mlttransitions.wipe_lumas.keys()
+    keys = list(mlttransitions.wipe_lumas.keys())
     keys.sort()
     for k in keys:
         wipe_luma_combo_box.append_text(k)
@@ -341,12 +295,20 @@ def get_transition_panel(trans_data):
     filler = Gtk.Label()
     filler.set_size_request(10,10)
 
-    out_clip_label = Gtk.Label(label=_("First Clip Out Handle:"))
+    out_clip_label = Gtk.Label(label=_("First Clip Out Handle Available/Required:"))
     out_clip_value = Gtk.Label(label=str(trans_data["from_handle"]) + _(" frame(s)"))
     
+    in_clip_label = Gtk.Label(label=_("Second Clip In Handle Available/Required:"))
+    in_clip_value = Gtk.Label(label=str(trans_data["to_handle"]) + _(" frame(s)"))
+
     in_clip_label = Gtk.Label(label=_("Second Clip In Handle:"))
     in_clip_value = Gtk.Label(label=str(trans_data["to_handle"]) + _(" frame(s)"))
+
+    steal_frames = Gtk.CheckButton()
+    steal_frames.set_active(editorstate.steal_frames)
     
+    steal_check_row = guiutils.get_checkbox_row_box(steal_frames, Gtk.Label(label=_("Steal frames from clips if needed")))
+
     out_handle_row = get_two_column_box(out_clip_label, 
                                         out_clip_value)
     in_handle_row = get_two_column_box(in_clip_label, 
@@ -377,6 +339,8 @@ def get_transition_panel(trans_data):
     data_vbox = Gtk.VBox(False, 2)
     data_vbox.pack_start(out_handle_row, False, False, 0)
     data_vbox.pack_start(in_handle_row, False, False, 0)
+    data_vbox.pack_start(guiutils.pad_label(4,4), False, False, 0)
+    data_vbox.pack_start(steal_check_row, False, False, 0)
     
     enconding_vbox = Gtk.VBox(False, 2)
     enconding_vbox.pack_start(encodings_cb, False, False, 0)
@@ -389,7 +353,7 @@ def get_transition_panel(trans_data):
 
     alignment = guiutils.set_margins(vbox, 12, 24, 12, 12)
 
-    return (alignment, type_combo_box, length_entry, encodings_cb, quality_cb, wipe_luma_combo_box, color_button)
+    return (alignment, type_combo_box, length_entry, encodings_cb, quality_cb, wipe_luma_combo_box, color_button, steal_frames)
 
 def get_transition_re_render_panel(trans_data):
     transition_length = trans_data["clip"] .clip_out - trans_data["clip"].clip_in + 1 # +1 out inclusive
