@@ -23,7 +23,7 @@ corresponding mlt.Producers for timeline.
 """
 import cairo
 import copy
-import md5
+import hashlib
 
 from gi.repository import Gtk, Gdk
 
@@ -36,6 +36,7 @@ from editorstate import PROJECT
 import gui
 import mltrefhold
 import respaths
+import userfolders
 import utils
 
 # Pattern producer types
@@ -201,10 +202,11 @@ class AbstractBinClip: # not extends projectdata.MediaFile? too late, too late.
         return True # these are created to match project profile
 
     def create_mlt_producer(self, profile):
-        print "create_mlt_producer not implemented"
+        print("create_mlt_producer not implemented")
 
     def create_icon(self):
-        print "patter producer create_icon() not implemented"
+        print("patter producer create_icon() not implemented")
+
 
 class BinColorClip(AbstractBinClip):
     """
@@ -225,8 +227,8 @@ class BinColorClip(AbstractBinClip):
         cr.rectangle(0, 0, width + 1, height+ 1)
         cr.fill()
 
-        file_name =  md5.new(self.gdk_color_str + str(width) + str(height)).hexdigest()      
-        write_file_path = utils.get_hidden_user_dir_path() + appconsts.RENDERED_CLIPS_DIR + "/" + file_name + ".png"
+        file_name = hashlib.md5((self.gdk_color_str + str(width) + str(height)).encode('utf-8')).hexdigest()      
+        write_file_path = userfolders.get_render_dir() + "/" + file_name + ".png"
         surface.write_to_png(write_file_path)
         
         producer = mlt.Producer(profile, write_file_path)
@@ -241,6 +243,7 @@ class BinColorClip(AbstractBinClip):
         cr.fill()
         self.icon = surface
 
+
 class BinNoiseClip(AbstractBinClip):
     def __init__(self, id, name):
         AbstractBinClip.__init__(self, id, name)
@@ -254,6 +257,7 @@ class BinNoiseClip(AbstractBinClip):
     def create_icon(self):
         self.icon = cairo.ImageSurface.create_from_png(respaths.PATTERN_PRODUCER_PATH + "noise_icon.png")
 
+
 class BinColorBarsClip(AbstractBinClip):
     def __init__(self, id, name):
         AbstractBinClip.__init__(self, id, name)
@@ -266,6 +270,7 @@ class BinColorBarsClip(AbstractBinClip):
 
     def create_icon(self):
         self.icon = cairo.ImageSurface.create_from_png(respaths.PATTERN_PRODUCER_PATH + "bars_icon.png")
+      
         
 class BinIsingClip(AbstractBinClip):
     def __init__(self, id, name):
@@ -350,8 +355,8 @@ class BinCountClip(AbstractBinClip):
 def _color_clip_dialog(callback):
     dialog = Gtk.Dialog(_("Create Color Clip"), None,
                     Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                    (_("Cancel").encode('utf-8'), Gtk.ResponseType.REJECT,
-                    _("Create").encode('utf-8'), Gtk.ResponseType.ACCEPT))
+                    (_("Cancel"), Gtk.ResponseType.REJECT,
+                    _("Create"), Gtk.ResponseType.ACCEPT))
 
     name_entry = Gtk.Entry()
     name_entry.set_text(_("Color Clip"))   
@@ -383,8 +388,8 @@ def _color_clip_dialog(callback):
 def _ising_clip_dialog(callback):
     dialog = Gtk.Dialog(_("Create Ising Clip"), None,
                     Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                    (_("Cancel").encode('utf-8'), Gtk.ResponseType.REJECT,
-                    _("Create").encode('utf-8'), Gtk.ResponseType.ACCEPT))
+                    (_("Cancel"), Gtk.ResponseType.REJECT,
+                    _("Create"), Gtk.ResponseType.ACCEPT))
  
     n_box, n_slider = guiutils.get_non_property_slider_row(0, 100, 1)
     bg_box, bg_slider = guiutils.get_non_property_slider_row(0, 100, 1)
@@ -414,8 +419,8 @@ def _ising_clip_dialog(callback):
 def _color_pulse_clip_dialog(callback):
     dialog = Gtk.Dialog(_("Create Color Pulse Clip"), None,
                     Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                    (_("Cancel").encode('utf-8'), Gtk.ResponseType.REJECT,
-                    _("Create").encode('utf-8'), Gtk.ResponseType.ACCEPT))
+                    (_("Cancel"), Gtk.ResponseType.REJECT,
+                    _("Create"), Gtk.ResponseType.ACCEPT))
 
     s1_box, s1_slider = guiutils.get_non_property_slider_row(0, 100, 1, 100)
     s2_box, s2_slider = guiutils.get_non_property_slider_row(0, 100, 1, 100)
