@@ -27,16 +27,20 @@ extending AbstractProperty class for editing. These wrappers convert
 edit inputs into mlt property values (that effect how sequence is displayed)
 and python side values (that are persistant).
 """
+import json
 
 from gi.repository import Gtk, Gdk
 
 import appconsts
 from editorstate import current_sequence
+import gui
 import mlttransitions
 import mltfilters
 import propertyparse
 import utils
 
+import traceback
+
 # keys                                                      meaning of values for this key
 RANGE_IN = "range_in"                                       # values define user input range
 RANGE_OUT = "range_out"                                     # values define range of output to mlt
@@ -53,10 +57,11 @@ NORMALIZED_FLOAT = "NORMALIZED_FLOAT"                       # range 0.0 - 1.0
 #  PROP_EXPRESSION values, e.g. "exptype=keyframe_hcs"      parsed output
 DEFAULT = "default"                                         # value     (str(int), str(float) or str(str))
 DEFAULT_TRANSITION = "default_transition"                   # value     (str(int), str(float) or str(str))
-SINGLE_KEYFRAME = "singlekeyframe"                          # 0=value
+SINGLE_KEYFRAME = "singlekeyframe"                          # DEPRECATED, were juat presenting standart slider for these now. This kept for back wards compatibility.
 OPACITY_IN_GEOM_SINGLE_KF = "opacity_in_geom_kf_single"     # 0=0/0:SCREEN_WIDTHxSCREEN_HEIGHT:opacity
 OPACITY_IN_GEOM_KF = "opacity_in_geom_kf"                   # frame=0/0:SCREEN_WIDTHxSCREEN_HEIGHT:opacity (kf_str;kf_str;kf_str;...;kf_str)
 GEOMETRY_OPACITY_KF ="geom_opac_kf"                         # frame=x/y:widthxheight:opacity
+GEOMETRY_RECT_FILTER_KF = "geom_filt_rect_kf"               # frame=x y w h 1  with 1 being constant for full opacity
 GEOM_IN_AFFINE_FILTER = "geom_in_affine_filt"               # x/y:widthxheight:opacity
 GEOM_IN_AFFINE_FILTER_V2 =  "geom_in_affine_filt_v2"        # x/y:widthxheight:opacity
 AFFINE_SCALE = "affine_scale"                               # special property to get the 1/ x that the filter wants
@@ -66,9 +71,12 @@ MULTIPART_KEYFRAME_HCS = "multipart_keyframe"               # frame=value(;frame
 FREI_POSITION_HCS = "frei_pos_hcs"                          # frame=x:y
 FREI_GEOM_HCS_TRANSITION = "frei_geom_hcs";                 # time=x:y:x_scale:y_scale:rotation:mix
 COLOR = "color"                                             # #rrggbb
+CAIRO_COLOR = "cairo_color"                                             # #rrggbb but displayed as r and b switched
 LUT_TABLE = "lut_table"                                     # val;val;val;val;...;val
 WIPE_RESOURCE = "wipe_resource"                             # /path/to/resource.pgm
+FILTER_WIPE_RESOURCE = "filter_wipe_resource"               # /path/to/resource.pgm
 FILE_RESOURCE = "file_resource"                             # /path/to/somefile
+ROTO_JSON = "roto_json"                                     # JSON string of keyframes and values
 PLAIN_STRING = "plain_string"                               # String is just string, for text input
 NOT_PARSED = "not_parsed"                                   # A write out value is not parsed from value
 NOT_PARSED_TRANSITION = "not_parsed_transition"             # A write out value is not parsed from value in transition object
@@ -115,24 +123,26 @@ def get_filter_editable_properties(clip, filter_object, filter_index,
     return editable_properties
 
 def _create_editable_property(p_type, args_str, params):
-    
+
+    args = propertyparse.args_string_to_args_dict(args_str)
+
+    try:
+        exp_type = args[EXPRESSION_TYPE] 
+    except:
+        # This fails for PROP_INT and PROP_FLOAT properties that are edited as keyframe properties.
+        # The given exp_type is irrelevant when set for PROP_INT and PROP_FLOAT but causes crashes/undetermined behaviour if exp_type not set correctly in filters.xml
+        # when required.
+        exp_type = SINGLE_KEYFRAME
+        
     if p_type == appconsts.PROP_EXPRESSION:
         """
         For expressions we can't do straight input output numerical
-        conversion so we need a extending class for expression type.
+        conversion so we need an extending class for expression type.
         """
-        args = propertyparse.args_string_to_args_dict(args_str)
-        
-        try:
-            exp_type = args[EXPRESSION_TYPE] 
-        except:
-            # This fails PROP_INT and PROP_FLOAT properties that are edited as keyframe properties and 
-            # they will be treated as exptype = SINGLE_KEYFRAME properties.
-            # This will now hide 'exptype' args in filters.xml, so they must be there set correctly.
-            exp_type = SINGLE_KEYFRAME
-        
         creator_func = EDITABLE_PROPERTY_CREATORS[exp_type]
         ep = creator_func(params)
+    elif exp_type == AFFINE_SCALE:
+        ep = AffineScaleProperty(params) # This needs special casing because slider input is a number and output value is inverse of input, not a linear range conversion.
     else:
         """
         Properties with single numerical values (int or float) can be handled with objects of EditableProperty class.
@@ -175,7 +185,15 @@ def get_non_mlt_editable_properties(clip, filter_object, filter_index):
     for i in range(0, len(filter_object.non_mlt_properties)):
         prop = filter_object.non_mlt_properties[i]
         p_name, p_value, p_type = prop
-        args_str = filter_object.info.property_args[p_name]
+        try:
+            args_str = filter_object.info.property_args[p_name]
+        except:
+            # We added new parameter to rotomask after release and need fix data here.
+            # For all normal filters just create new filter, but rotomask is such a complex beast that this was needed.
+            if p_name == "mask_type":
+                args_str = "editor=no_editor"
+                filter_object.info.property_args[p_name] = args_str
+
         ep = NonMltEditableProperty(prop, args_str, clip, filter_index, i)
         editable_properties.append(ep)
     
@@ -188,7 +206,8 @@ class AbstractProperty:
     mltfilters.FilterObject.properties array and in
     mlttransitions.CompositorObject.transition.properties array.
 
-    This class converts input to output using set ranges.
+    This class and all extending classes convert input to output using set ranges or
+    other GUI editors. GUI input -> MLT property value.
     
     Class also creates args name->value dict used by all extending classes
     and has default versions of editor component callbacks.
@@ -275,7 +294,8 @@ class AbstractProperty:
             step = DEFAULT_STEP
         lower, upper = self.input_range
         value = self.get_current_in_value()
-        return Gtk.Adjustment(float(value), float(lower), float(upper), float(step))
+
+        return Gtk.Adjustment(value=float(value), lower=float(lower), upper=float(upper), step_incr=float(step))
     
     def adjustment_value_changed(self, adjustment):
         value = adjustment.get_value()
@@ -291,7 +311,7 @@ class AbstractProperty:
         self.write_value(val)
         
     def color_selected(self, color_button):
-        print "color_selected() not overridden"
+        print("color_selected() not overridden")
 
     def combo_selection_changed(self, combo_box, values):
         value = values[combo_box.get_active()]
@@ -301,14 +321,14 @@ class AbstractProperty:
         """
         This has to be overridden by all extending classes.
         """
-        print "write_value() not overridden"
+        print("write_value() not overridden")
     
     def write_out_keyframes(self, keyframes):
         """
         This has to be overridden by extending classes 
         edited with keyframe editor.
         """
-        print "write_out_keyframes() not overridden"
+        print("write_out_keyframes() not overridden")
         
     def get_clip_length(self):
         return self.clip.clip_out - self.clip.clip_in + 1
@@ -323,10 +343,13 @@ class AbstractProperty:
         return (float(current_sequence().profile.sample_aspect_num()) / 
                     current_sequence().profile.sample_aspect_den())
        
-        
+    def enable_save_menu_item(self):
+        gui.editor_window.uimanager.get_widget("/MenuBar/FileMenu/Save").set_sensitive(True)
+
+    
 class EditableProperty(AbstractProperty):
     """
-    A wrapper for mltfilter.FilterObject.properties array property tuple 
+    A wrapper for a mltfilter.FilterObject.properties array property tuple 
     and related data that converts user input to 
     property values.
 
@@ -453,6 +476,9 @@ class NonMltEditableProperty(AbstractProperty):
     def _get_filter_object(self):
         return self.clip.filters[self.filter_index]
 
+    def write_value(self, val):
+        pass # There has not defined need for this.
+
     def write_number_value(self, numb):
         self.write_property_value(str(numb))
 
@@ -481,7 +507,8 @@ class SingleKeyFrameProperty(EditableProperty):
         val = self.value.strip('"')
         epxr_sides = val.split("=")
         in_value = self.get_in_value(float(epxr_sides[1]))
-        return Gtk.Adjustment(float(in_value), float(lower), float(upper), float(step))
+
+        return Gtk.Adjustment(value=float(in_value), lower=float(lower), upper=float(upper), step_incr=float(step))
 
     def adjustment_value_changed(self, adjustment):
         value = adjustment.get_value()
@@ -504,6 +531,7 @@ class AffineFilterGeomProperty(EditableProperty):
         val_str = "0=" + str(x) + "/" + str(y) + ":" + str(w) + "x" + str(h) + ":100" # 100x MLT ignores width
         self.write_value(val_str)
 
+
 class AffineFilterGeomPropertyV2(EditableProperty):
     """
     Converts values of four sliders to position and size info
@@ -518,6 +546,7 @@ class AffineFilterGeomPropertyV2(EditableProperty):
         val_str = "0=" + str(x) + "/" + str(y) + ":" + str(w) + "x" + str(height) + ":100" # 100x MLT does translate for height
         self.write_value(val_str)
 
+
 class FreiPosHCSFilterProperty(EditableProperty):    
     def adjustment_value_changed(self, adjustment):
         value = adjustment.get_value()
@@ -525,6 +554,7 @@ class FreiPosHCSFilterProperty(EditableProperty):
         val_str = "0=" + str(out_value)
         self.write_value(val_str)
 
+
 class OpacityInGeomSKFProperty(TransitionEditableProperty):
     """
     Converts adjustments to expressions like "0/0:720x576:76" for
@@ -545,7 +575,8 @@ class OpacityInGeomSKFProperty(TransitionEditableProperty):
             step = DEFAULT_STEP
         lower, upper = self.input_range
         in_value = self.get_in_value(float(self.value_parts[2]))
-        return Gtk.Adjustment(float(in_value), float(lower), float(upper), float(step))
+
+        return Gtk.Adjustment(value=float(in_value), lower=float(lower), upper=float(upper), step_incr=float(step))
 
     def adjustment_value_changed(self, adjustment):
         value = adjustment.get_value()
@@ -574,7 +605,8 @@ class OpacityInGeomKeyframeProperty(TransitionEditableProperty):
             step = DEFAULT_STEP
         lower, upper = self.input_range
         in_value = self.get_in_value(float(self.value_parts[2]))
-        return Gtk.Adjustment(float(in_value), float(lower), float(upper), float(step))
+
+        return Gtk.Adjustment(value=float(in_value), lower=float(lower), upper=float(upper), step_incr=float(step))
 
     def write_out_keyframes(self, keyframes):
         # key frame array of tuples (frame, opacity)
@@ -632,7 +664,7 @@ class KeyFrameGeometryOpacityProperty(TransitionEditableProperty):
             step = DEFAULT_STEP
         lower, upper = self.input_range
 
-        return Gtk.Adjustment(float(1.0), float(lower), float(upper), float(step)) # Value set later to first kf value
+        return Gtk.Adjustment(value=float(1.0), lower=float(lower), upper=float(upper), step_incr=float(step)) # Value set later to first kf value
 
     def write_out_keyframes(self, keyframes):
         # key frame array of tuples (frame, [x, y, width, height], opacity)
@@ -648,6 +680,29 @@ class KeyFrameGeometryOpacityProperty(TransitionEditableProperty):
         self.write_value(val_str)
 
 
+class KeyFrameFilterGeometryRectProperty(EditableProperty):
+
+    def get_input_range_adjustment(self):
+        # Returns DUMMY noop Adjustment tht needs to exist because AbstrackKeyframeEditor assumes a slider always exists,
+        # but this not the case for this editor/property pair.
+  
+        return Gtk.Adjustment(value=float(1.0), lower=float(0.0), upper=float(1.0), step_incr=float(0.01)) # Value set later to first kf value
+        
+    def write_out_keyframes(self, keyframes):       
+        # key frame array of tuples (frame, [x, y, width, height], opacity)
+        val_str = ""
+        for kf in keyframes:
+            frame, rect, opac = kf
+            val_str += str(int(frame)) + "=" # frame
+            val_str += str(int(rect[0])) + " " + str(int(rect[1])) + " " # pos
+            val_str += str(int(rect[2])) + " " + str(int(rect[3])) + " " # size
+            val_str += "1"
+            val_str += str(self.get_out_value(opac)) + ";" # opac with converted range from slider
+        
+        val_str = val_str.strip(";")
+        self.write_value(val_str)
+
+ 
 class FreiGeomHCSTransitionProperty(TransitionEditableProperty):
     def __init__(self, params):
         TransitionEditableProperty.__init__(self, params)
@@ -663,7 +718,8 @@ class KeyFrameHCSFilterProperty(EditableProperty):
         except:
             step = DEFAULT_STEP
         lower, upper = self.input_range
-        return Gtk.Adjustment(float(0.1), float(lower), float(upper), float(step)) # Value set later to first kf value
+ 
+        return Gtk.Adjustment(value=float(0.1), lower=float(lower), upper=float(upper), step_incr=float(step)) # Value set later to first kf value
         
     def write_out_keyframes(self, keyframes):
         val_str = ""
@@ -675,6 +731,21 @@ class KeyFrameHCSFilterProperty(EditableProperty):
         self.write_value(val_str)
 
 
+class RotoJSONProperty(EditableProperty):
+
+    def write_out_keyframes(self, keyframes):
+        self.enable_save_menu_item()
+        val_str = "{"
+        for kf_obj in keyframes:
+            kf, points = kf_obj
+            val_str += '"' + str(kf) + '"' + ':'
+            val_str += json.dumps(points) + ","
+        
+        val_str = val_str.rstrip(",")
+        val_str += "}"
+        self.write_value(val_str)
+
+
 class KeyFrameHCSTransitionProperty(TransitionEditableProperty):
     """
     Coverts array of keyframe tuples to string of type "0=0.2;123=0.143"
@@ -688,7 +759,8 @@ class KeyFrameHCSTransitionProperty(TransitionEditableProperty):
         except:
             step = DEFAULT_STEP
         lower, upper = self.input_range
-        return Gtk.Adjustment(float(0.1), float(lower), float(upper), float(step)) # Value set later to first kf value
+
+        return Gtk.Adjustment(value=float(0.1), lower=float(lower), upper=float(upper), step_incr=float(step)) # Value set later to first kf value
 
     def write_out_keyframes(self, keyframes):
         val_str = ""
@@ -703,10 +775,11 @@ class KeyFrameHCSTransitionProperty(TransitionEditableProperty):
 class ColorProperty(EditableProperty):
     """
     Gives value as gdk color for gui and writes out color as 
-    different type of hex to mlt 
+    different type of hex to mlt.
     """
     
     def get_value_as_gdk_color(self):
+        # NOT USED ?!?
         raw_r, raw_g, raw_b = utils.hex_to_rgb(self.value)
         return Gdk.Color(red=(float(raw_r)/255.0),
                              green=(float(raw_g)/255.0),
@@ -724,6 +797,34 @@ class ColorProperty(EditableProperty):
                         utils.int_to_hex_str(int(raw_b * 255.0))
         self.write_value(val_str)
 
+
+class CairoColorProperty(EditableProperty):
+    """
+    Gives value as gdk color for gui and writes out color as 
+    different type of hex to mlt, for uses R and B switched,
+    there is something gone wrom
+    """
+    
+    def get_value_as_gdk_color(self):
+        # NOT USED ?!?
+        raw_r, raw_g, raw_b = utils.hex_to_rgb(self.value)
+        return Gdk.Color(red=(float(raw_b)/255.0),
+                             green=(float(raw_g)/255.0),
+                             blue=(float(raw_r)/255.0))
+
+    def get_value_rgba(self):
+        raw_r, raw_g, raw_b = utils.hex_to_rgb(self.value)
+        return (float(raw_b)/255.0, float(raw_g)/255.0, float(raw_r)/255.0, 1.0)
+
+    def color_selected(self, color_button):
+        color = color_button.get_color()
+        raw_r, raw_g, raw_b = color.to_floats()
+        val_str = "#" + utils.int_to_hex_str(int(raw_b * 255.0)) + \
+                        utils.int_to_hex_str(int(raw_g * 255.0)) + \
+                        utils.int_to_hex_str(int(raw_r * 255.0))
+        self.write_value(val_str)
+
+
 class WipeResourceProperty(TransitionEditableProperty):
     """
     Converts user combobox selections to absolute paths containing wipe
@@ -736,7 +837,22 @@ class WipeResourceProperty(TransitionEditableProperty):
         key = keys[combo_box.get_active()]
         res_path = mlttransitions.get_wipe_resource_path(key)
         self.write_value(str(res_path))
-        
+
+
+class FilterWipeResourceProperty(EditableProperty):
+    """
+    Converts user combobox selections to absolute paths containing wipe
+    resource images.
+    """
+    def __init__(self, params):
+        EditableProperty.__init__(self, params)
+
+    def combo_selection_changed(self, combo_box, keys):
+        key = keys[combo_box.get_active()]
+        res_path = mlttransitions.get_wipe_resource_path(key)
+        self.write_value(str(res_path))
+    
+    
 class FileResourceProperty(EditableProperty):
     """
     A file path as property value set from file chooser dialog callback.
@@ -744,10 +860,11 @@ class FileResourceProperty(EditableProperty):
     def dialog_response_callback(self, dialog, response_id):
         res_path = dialog.get_filename()
         if response_id == Gtk.ResponseType.ACCEPT and res_path != None:
-            self.write_value(unicode(str(res_path), "utf-8"))
+            self.write_value(str(res_path))
         else:
-            self.write_value(unicode(str(""), "utf-8"))
-        
+            self.write_value(str(""))
+
+
 class MultipartKeyFrameProperty(AbstractProperty):
     
     def __init__(self, params):
@@ -766,7 +883,7 @@ class MultipartKeyFrameProperty(AbstractProperty):
             step = DEFAULT_STEP
         lower, upper = self.input_range
 
-        return Gtk.Adjustment(float(0.1), float(lower), float(upper), float(step)) # Value set later to first kf value
+        return Gtk.Adjustment(value=float(0.1), lower=float(lower), upper=float(upper), step_incr=float(step)) # Value set later to first kf value
 
     def write_out_keyframes(self, keyframes):
         val_str = ""
@@ -780,51 +897,134 @@ class MultipartKeyFrameProperty(AbstractProperty):
 
 
 class AffineScaleProperty(EditableProperty):
-    
-    def get_input_range_adjustment(self):
-        step = DEFAULT_STEP
-        lower = 0
-        upper = 500
-        val = self.value.strip('"')
-        epxr_sides = val.split("=")
-        in_value = self.get_in_value(float(epxr_sides[1]))
-        return Gtk.Adjustment(float(in_value), float(lower), float(upper), float(step))
-
-    def adjustment_value_changed(self, adjustment):
-        value = adjustment.get_value()
-        out_value = self.get_out_value(value)
-        val_str = "0=" + str(out_value)
-        self.write_value(val_str)
 
     def get_out_value(self, in_value):
         """
         Converts input value to output value using ranges.
         """
-        # in_range = 500 # hard coded special case
-        in_norm = in_value / 100.0 # to get 0 - 5, 1.0 no scaling
+        in_norm = float(in_value) / 100.0
         if in_norm < 0.001:
             in_norm = 0.001
-        out =  1 / in_norm
-        return out
+        out =  1.0 / in_norm
 
     def get_in_value(self, out_value):
         """
         Converts output to input value
         """
-        # out_value =  1 / in_norm, range 1 / 0.001 -> 1 / 5
         if out_value < 0.001:
             out_value = 0.001
-        in_value = (1 / (out_value)) * 100 # 0 - 500 range
+        in_value = (1.0 / float(out_value)) * 100.0
+
         return in_value  
 
-    def write_mlt_property_str_value(self, str_value):
-        val = str_value.strip('"')
-        epxr_sides = val.split("=")
-        # mlt property value
-        filter_object = self._get_filter_object()
-        filter_object.mlt_filter.set(str(self.name), str(epxr_sides[1]))
-        
 
+# ----------------------------------------------------------------------------- AFFINE FILTER TRANSFORM
+"""
+Refactor Affine Blend EditableProperty ducktyping object to be like the below instead of the current EmptyClass thing.
+
+class FilterAffineTransformEditableProperty:
+    
+    def __init__(self, clip, editable_properties):
+
+        # pack real properties to go
+        self.x = [ep for ep in editable_properties if ep.name == "transition.ox"][0]
+        self.y = [ep for ep in editable_properties if ep.name == "transition.oy"][0]
+        self.x_scale = [ep for ep in editable_properties if ep.name == "transition.scale_x"][0]
+        self.y_scale = [ep for ep in editable_properties if ep.name == "transition.scale_y"][0]
+        self.rotation = [ep for ep in editable_properties if ep.name == "transition.fix_rotate_x"][0]
+        self.opacity = [ep for ep in editable_properties if ep.name == "opacity"][0]
+        # Screen width and height are needeed for anchor point related conversions
+        self.profile_width = current_sequence().profile.width()
+        self.profile_height = current_sequence().profile.height()
+        #self.aspect_ratio = float(self.profile_width) / self.profile_height
+        # duck type methods, using opacity is not meaningful, any property with clip member could do
+        self.clip = self.x.clip
+        self.get_clip_tline_pos = lambda : clip.clip_in # clip is compositor, compositor in and out points straight in timeline frames
+        self.get_clip_length = lambda : clip.get_length()
+        self.get_input_range_adjustment = lambda : Gtk.Adjustment(float(100), float(0), float(100), float(1))
+        self.get_display_name = lambda : "GGSFSF"
+        self.get_pixel_aspect_ratio = lambda : (float(current_sequence().profile.sample_aspect_num()) / current_sequence().profile.sample_aspect_den())
+        self.get_in_value = lambda out_value : out_value # hard coded for opacity 100 -> 100 range
+        self.write_out_keyframes = lambda w_kf : self._rotating_ge_write_out_keyframes(w_kf)
+        self.update_prop_value = lambda : self._noop()
+
+        value = self._get_initial_value_str()
+        self.value = value.strip(";")
+
+    def _get_initial_value_str(self):
+        # duck type members
+        x_tokens = self.x.value.split(";")
+        y_tokens = self.y.value.split(";")
+        x_scale_tokens = self.x_scale.value.split(";")
+        y_scale_tokens = self.y_scale.value.split(";")
+        rotation_tokens = self.rotation.value.split(";")
+        opacity_tokens = self.opacity.value.split(";")
+        
+        value = ""
+        for i in range(0, len(x_tokens)): # these better match, same number of keyframes for all values, or this will not work
+            frame, x = x_tokens[i].split("=")
+            x = -float(x) + float(self.profile_width) / 2.0 # -x is how MLT wants this param, offset is to make editor and output match 
+            frame, y = y_tokens[i].split("=")
+            y = -float(y) + float(self.profile_height) / 2.0  # this how MLT want this param
+            frame, x_scale = x_scale_tokens[i].split("=")
+            x_scale = 1.0 / float(x_scale) # this how MLT want this param
+            frame, y_scale = y_scale_tokens[i].split("=")
+            y_scale = 1.0 / float(y_scale) # this how MLT want this param
+            frame, rotation = rotation_tokens[i].split("=")
+            frame, opacity = opacity_tokens[i].split("=")
+            opacity = 1.0 # we ae not editing this so let's make it alwaus constant
+            
+            frame_str = str(frame) + "=" + str(x) + ":" + str(y) + ":" + str(x_scale) + ":" + str(y_scale) + ":" + str(rotation) + ":" + str(opacity)
+            value += frame_str + ";"
+
+        return value
+
+    def _noop(self):
+        pass
+
+    def _rotating_ge_write_out_keyframes(self, keyframes):
+
+        x_val = ""
+        y_val = ""
+        x_scale_val = ""
+        y_scale_val = ""
+        rotation_val = ""
+        opacity_val = ""
+        
+        for kf in keyframes:
+            frame, transf, opacity = kf
+            x, y, x_scale, y_scale, rotation = transf
+            print (type(x), type(y), type(x_scale), type(y_scale), type(rotation))
+            print("X:", x, "Y:", y)
+            x_val += str(frame) + "=" + str(((-x)) + (float(self.profile_width)/2.0) * x_scale) + ";" # (self.profile_width/2.0)) editor thinks anchor point has been offset into middle of image, filter does this automatically.
+            y_val += str(frame) + "=" + str(((-y)) + (float(self.profile_height)/2.0) * y_scale) + ";"
+            x_scale_val += str(frame) + "=" + str(1.0/x_scale) + ";"
+            y_scale_val += str(frame) + "=" + str(1.0/y_scale) + ";"
+            rotation_val += str(frame) + "=" + str(rotation) + ";"
+            opacity_val += str(frame) + "=" + str(1.0) + ";"
+
+            print("KF ____________________________________________________________________")
+            print(x, y, x_scale, y_scale, rotation)
+            print(x_val, y_val, x_scale_val, y_scale_val, rotation_val)
+        
+        x_val = x_val.strip(";")
+        y_val = y_val.strip(";")
+        x_scale_val = x_scale_val.strip(";")
+        y_scale_val = y_scale_val.strip(";")
+        rotation_val = rotation_val.strip(";")
+        opacity_val = opacity_val.strip(";")
+       
+
+       
+        self.x.write_value(x_val)
+        self.y.write_value(y_val)
+        self.x_scale.write_value(x_scale_val)
+        self.y_scale.write_value(y_scale_val)
+        self.rotation.write_value(rotation_val)
+        self.opacity.write_value(opacity_val)
+
+        print("kf write done")
+"""
 # ------------------------------------------ creator func dicts
 # dict EXPRESSION_TYPE args value -> class extending AbstractProperty
 # Note: HCS means half comma separated
@@ -841,11 +1041,15 @@ EDITABLE_PROPERTY_CREATORS = { \
     KEYFRAME_HCS_TRANSITION: lambda params : KeyFrameHCSTransitionProperty(params),
     MULTIPART_KEYFRAME_HCS: lambda params : MultipartKeyFrameProperty(params),
     COLOR: lambda params : ColorProperty(params),
+    CAIRO_COLOR: lambda params : CairoColorProperty(params),
     GEOMETRY_OPACITY_KF: lambda params : KeyFrameGeometryOpacityProperty(params),
+    GEOMETRY_RECT_FILTER_KF: lambda params : KeyFrameFilterGeometryRectProperty(params),
     GEOM_IN_AFFINE_FILTER: lambda params : AffineFilterGeomProperty(params),
     GEOM_IN_AFFINE_FILTER_V2: lambda params :AffineFilterGeomPropertyV2(params),
     WIPE_RESOURCE : lambda params : WipeResourceProperty(params),
+    FILTER_WIPE_RESOURCE : lambda params : FilterWipeResourceProperty(params),
     FILE_RESOURCE : lambda params :FileResourceProperty(params),
+    ROTO_JSON  : lambda params :RotoJSONProperty(params),
     LUT_TABLE : lambda params  : LUTTableProperty(params),
     NOT_PARSED : lambda params : EditableProperty(params), # This should only be used with params that have editor=NO_EDITOR
     NOT_PARSED_TRANSITION : lambda params : TransitionEditableProperty(params), # This should only be used with params that have editor=NO_EDITOR
