@@ -19,7 +19,7 @@
 """
 
 """
-Module handles button edit events from buttons in the middle bar.
+Module handles button edit events from buttons in the middle bar and other non-tool edits targeting timeline.
 """
 
 
@@ -27,7 +27,8 @@ Module handles button edit events from buttons in the middle bar.
 from gi.repository import Gtk
 from gi.repository import Gdk
 
-import md5
+import copy
+import hashlib
 import os
 from operator import itemgetter
 import threading
@@ -65,13 +66,15 @@ import renderconsumer
 import respaths
 import sequence
 import syncsplitevent
+import tlinerender
 import updater
+import userfolders
 import utils
 
 
 # values for differentiating copy paste data
-COPY_PASTA_DATA_CLIPS = 1
-COPY_PASTA_DATA_COMPOSITOR_PROPERTIES = 2
+COPY_PASTE_DATA_CLIPS = appconsts.COPY_PASTE_DATA_CLIPS
+COPY_PASTE_DATA_COMPOSITOR_PROPERTIES = appconsts.COPY_PASTE_DATA_COMPOSITOR_PROPERTIES
 
 # Used to store transition render data to be used at render complete callback
 transition_render_data = None
@@ -91,6 +94,10 @@ def _get_new_clip_from_clip_monitor():
         new_clip = current_sequence().create_file_producer_clip(MONITOR_MEDIA_FILE().path, None, False, MONITOR_MEDIA_FILE().ttl)
     else:
         new_clip = current_sequence().create_pattern_producer(MONITOR_MEDIA_FILE())
+    
+    if MONITOR_MEDIA_FILE().container_data != None:
+        new_clip.container_data = copy.deepcopy(MONITOR_MEDIA_FILE().container_data)
+        new_clip.container_data.container_data.generate_clip_id()
         
     # Set clip in and out points
     new_clip.mark_in = MONITOR_MEDIA_FILE().mark_in
@@ -136,11 +143,11 @@ def cut_pressed():
         index = track.get_clip_index_at(int(tline_frame))
         try:
             clip = track.clips[index]            
-            # don't cut blanck clip
+            # don't cut blanck clips
             if clip.is_blanck_clip:
                 continue
         except Exception:
-            continue # Frame after last clip in track
+            continue # Frame is after last clip in track
 
         # Get cut frame in clip frames
         clip_start_in_tline = track.clip_start(index)
@@ -191,8 +198,8 @@ def sequence_split_pressed():
     # before we start we will ask the user whether he really wants to do, what he
     # just asked for. The intention of this is to provide some more background
     # information
-    heading = _("Split to new Sequence at Playhead Position")
-    info = _("Do you realy want to split this sequence into two?\nThis will create a new sequence receiving righthand content of your currently active sequence. Also the same content will be removed from your currently active sequence.\nThe newly created sequence will be opened.\n\n Continue?")
+    heading = _("Confirm split to new Sequence at Playhead position")
+    info = _("This will create a new sequence from the part after playhead. That part will be removed from\nyour current active sequence.\n\nThe newly created sequence will be opened as current sequence.")
     dialogutils.warning_confirmation(split_confirmed, heading, info, gui.editor_window.window)
 
 def split_confirmed(dialog, response_id):
@@ -456,10 +463,19 @@ def _attempt_clip_cover_delete(clip, track, index):
         cover_form_clip = track.clips[movemodes.selected_range_in - 1]
         cover_to_clip = track.clips[movemodes.selected_range_in + 1]
         
-        real_length = clip.get_length()
-        to_part = real_length / 2
+        real_length = clip.get_length() # this the mlt finction giving media length, not length on timeline
+
+        to_part = real_length // 2
         from_part = real_length - to_part
-    
+
+        # Fix lengths to match what existed before adding rendered transition
+        clip_marks_length = clip.clip_out - clip.clip_in
+        if clip_marks_length % 2 == 1:
+            to_part += -1
+        else:
+            from_part += 1
+            to_part += -1
+
         if to_part > cover_to_clip.clip_in:
             return False
         if from_part > cover_form_clip.get_length() - cover_form_clip.clip_out - 1:# -1, clip_out inclusive
@@ -516,7 +532,7 @@ def lift_button_pressed():
 
 
 def ripple_delete_button_pressed():
-    print "Ripple delete"
+    print("Ripple delete")
     if movemodes.selected_track == -1:
         return
 
@@ -655,10 +671,11 @@ def range_overwrite_pressed():
     mark_out_frame = current_sequence().tractor.mark_out
     
     # Case timeline marked
+    print(mark_in_frame, mark_out_frame, over_clip.mark_out, over_clip.mark_in)
     if mark_in_frame != -1 and mark_out_frame != -1:
         range_length = mark_out_frame - mark_in_frame + 1 # end is incl.
         if over_clip.mark_in == -1:
-            # This actually never hit because mark in and mark out seem to first and last frame if nothing set
+            # This actually should never be hit because mark in and mark out seem to first and last frame if nothing set
             show_three_point_edit_not_defined()
             return
 
@@ -672,19 +689,18 @@ def range_overwrite_pressed():
     # Case clip marked
     elif over_clip.mark_out != -1 and over_clip.mark_in != -1:
         range_length = over_clip.mark_out - over_clip.mark_in + 1 # end is incl.
-        
-        if mark_in_frame == -1:
-            show_three_point_edit_not_defined()
-            return
 
-        over_length = track.get_length() - mark_in_frame + 1 # + 1 out incl
-        if over_length < range_length:
-            monitor_clip_too_short(gui.editor_window.window)
-            return
-            
         over_clip_out = over_clip.mark_out
-        mark_out_frame = mark_in_frame + range_length - 1 # -1 because it gets readded later
-        
+        if mark_out_frame == -1:
+            # Mark in defined
+            mark_out_frame = mark_in_frame + range_length - 1 # -1 because it gets readded later
+        else:
+            # Mark out defined
+            mark_in_frame = mark_out_frame - range_length + 1
+            if mark_in_frame < 0:
+                clip_shortning = -mark_in_frame
+                mark_in_frame = 0
+                over_clip.mark_in = over_clip.mark_in + clip_shortning # moving overclip in forward because in needs to hit timeline frame 0
     # case neither clip or timeline has both in and out points
     else:
         show_three_point_edit_not_defined()
@@ -694,6 +710,7 @@ def range_overwrite_pressed():
 
     updater.save_monitor_frame = False # hack to not get wrong value saved in MediaFile.current_frame
 
+    #print((over_clip_out- over_clip.mark_in), (mark_out_frame + 1 - mark_in_frame))
     data = {"track":track,
             "clip":over_clip,
             "clip_in":over_clip.mark_in,
@@ -702,6 +719,7 @@ def range_overwrite_pressed():
             "mark_out_frame":mark_out_frame + 1} # +1 because mark is displayed and end of frame end this 
                                                  # confirms to user expectation of
                                                  # of how this should work
+    #print(data)
     action = edit.range_overwrite_action(data)
     action.do_edit()
 
@@ -787,38 +805,6 @@ def sync_compositor(compositor):
     action = edit.move_compositor_action(data)
     action.do_edit()
         
-def set_compositors_fades_defaults():
-    dialogs.set_fades_defaults_dialog(_compositors_fades_defaults_callback)
-
-def _compositors_fades_defaults_callback(dialog, response_id, widgets):
-    group_select, fade_in_check, fade_in_spin, fade_out_check, fade_out_spin, fade_in_length_label, fade_out_length_label = widgets
-    
-    group = group_select.get_active()
-    fade_in_on = fade_in_check.get_active()
-    fade_in_length = int(fade_in_spin.get_value())
-    fade_out_on = fade_out_check.get_active()
-    fade_out_length = int(fade_out_spin.get_value())
-
-    dialog.destroy()
-    
-    if group == 0:
-        fade_in_key = appconsts.P_PROP_DISSOLVE_GROUP_FADE_IN
-        fade_out_key = appconsts.P_PROP_DISSOLVE_GROUP_FADE_OUT
-    else:
-        fade_in_key = appconsts.P_PROP_ANIM_GROUP_FADE_IN
-        fade_out_key = appconsts.P_PROP_ANIM_GROUP_FADE_OUT
-
-    if fade_in_on == False or fade_in_length == 0:
-        PROJECT().set_project_property(fade_in_key, -1)
-    else:
-        PROJECT().set_project_property(fade_in_key, fade_in_length)
-        
-    if fade_out_on == False or fade_out_length == 0:
-        PROJECT().set_project_property(fade_out_key, -1)
-    else:
-        PROJECT().set_project_property(fade_out_key, fade_out_length)
-
-
 def split_audio_button_pressed():
     if movemodes.selected_track == -1:
         return
@@ -834,57 +820,15 @@ def split_audio_button_pressed():
     syncsplitevent.split_audio_from_clips_list(clips, track)
 
 def sync_all_compositors():
-    full_sync_data = edit.get_full_compositor_sync_data()
+    full_sync_data, orphaned_compositors = edit.get_full_compositor_sync_data()
     
     for sync_item in full_sync_data:
-        destroy_id, orig_in, orig_out, clip_start, clip_end = sync_item
+        destroy_id, orig_in, orig_out, clip_start, clip_end, clip_track, orig_compositor_track = sync_item
         compositor = current_sequence().get_compositor_for_destroy_id(destroy_id)
         data = {"compositor":compositor,"clip_in":clip_start,"clip_out":clip_end}
         action = edit.move_compositor_action(data)
         action.do_edit()
 
-    """
-    # Pair all compositors with their origin clips ids
-    comp_clip_pairings = {}
-    for compositor in current_sequence().compositors:
-        if compositor.origin_clip_id in comp_clip_pairings:
-            comp_clip_pairings[compositor.origin_clip_id].append(compositor)
-        else:
-            comp_clip_pairings[compositor.origin_clip_id] = [compositor]
-    
-    # Create resync list
-    resync_list = []
-    for i in range(current_sequence().first_video_index, len(current_sequence().tracks) - 1): # -1, there is a topmost hidden track 
-        track = current_sequence().tracks[i] # b_track is source track where origin clip is
-        for j in range(0, len(track.clips)):
-            clip = track.clips[j]
-            if clip.id in comp_clip_pairings:
-                compositor_list = comp_clip_pairings[clip.id]
-                for compositor in compositor_list:
-                    resync_list.append((clip, track, j, compositor))
-                    
-    # Do sync
-    for resync_item in resync_list:
-        try:
-            clip, track, clip_index, compositor = resync_item
-            clip_start = track.clip_start(clip_index)
-            clip_end = clip_start + clip.clip_out - clip.clip_in
-            
-            # Auto fades need to go to start or end of clips and maintain their lengths
-            if compositor.transition.info.auto_fade_compositor == True:
-                if compositor.transition.info.name == "##auto_fade_in":
-                    clip_end = clip_start + compositor.get_length() - 1
-                else:
-                    clip_start = clip_end - compositor.get_length() + 1
-            
-            data = {"compositor":compositor,"clip_in":clip_start,"clip_out":clip_end}
-            action = edit.move_compositor_action(data)
-            action.do_edit()
-        except:
-            # Clip is probably deleted
-            pass
-    """
-    
 def add_transition_menu_item_selected():
     if movemodes.selected_track == -1:
         # INFOWINDOW
@@ -898,7 +842,7 @@ def add_transition_menu_item_selected():
     
 def add_fade_menu_item_selected():
     if movemodes.selected_track == -1:
-        print "so selection track"
+        print("so selection track")
         # INFOWINDOW
         return
 
@@ -910,7 +854,7 @@ def add_fade_menu_item_selected():
 
 def add_transition_pressed(retry_from_render_folder_select=False):
     if movemodes.selected_track == -1:
-        print "so selection track"
+        print("so selection track")
         # INFOWINDOW
         return
 
@@ -919,21 +863,13 @@ def add_transition_pressed(retry_from_render_folder_select=False):
 
     if not ((clip_count == 2) or (clip_count == 1)):
         # INFOWINDOW
-        print "clip count"
+        print("clip count")
         return
 
     if track.id < current_sequence().first_video_index and clip_count == 1:
         _no_audio_tracks_mixing_info()
         return
 
-    if editorpersistance.prefs.render_folder == None:
-        if retry_from_render_folder_select == True:
-            return
-        dialogs.select_rendred_clips_dir(_add_transition_render_folder_select_callback,
-                                         gui.editor_window.window,
-                                         editorpersistance.prefs.render_folder)
-        return
-
     if clip_count == 2:
         _do_rendered_transition(track)
     else:
@@ -981,56 +917,39 @@ def get_transition_data_for_clips(track, from_clip, to_clip):
                        "max_length":max_length}
     return transition_data
 
-def _add_transition_render_folder_select_callback(dialog, response_id, file_select):
-    try:
-        folder = file_select.get_filenames()[0]
-    except:
-        dialog.destroy()
-        return
-
-    dialog.destroy()
-    if response_id == Gtk.ResponseType.YES:
-        if folder ==  os.path.expanduser("~"):
-            dialogs.rendered_clips_no_home_folder_dialog()
-        else:
-            editorpersistance.prefs.render_folder = folder
-            editorpersistance.save()
-            add_transition_pressed(True)
-
 def _add_transition_dialog_callback(dialog, response_id, selection_widgets, transition_data):
     if response_id != Gtk.ResponseType.ACCEPT:
         dialog.destroy()
         return
 
     # Get input data
-    type_combo, length_entry, enc_combo, quality_combo, wipe_luma_combo_box, color_button = selection_widgets
+    type_combo, length_entry, enc_combo, quality_combo, wipe_luma_combo_box, color_button, steal_frames = selection_widgets
     transition_type_selection_index = type_combo.get_active()
     encoding_option_index = enc_combo.get_active()
     quality_option_index = quality_combo.get_active()
     extension_text = "." + renderconsumer.encoding_options[encoding_option_index].extension
     sorted_wipe_luma_index = wipe_luma_combo_box.get_active()
     color_str = color_button.get_color().to_string()
+    force_steal_frames = steal_frames.get_active()
+    editorstate.steal_frames = force_steal_frames # making this selection as default for next invocation
 
     try:
         length = int(length_entry.get_text())
-    except Exception, e:
+    except Exception as e:
         # INFOWINDOW, bad input
-        print str(e)
-        print "entry"
+        print(str(e))
+        print("entry")
         return
 
     dialog.destroy()
 
-    # Save encoding
-    PROJECT().set_project_property(appconsts.P_PROP_TRANSITION_ENCODING,(encoding_option_index,quality_option_index))
-
     from_clip = transition_data["from_clip"]
     to_clip = transition_data["to_clip"]
 
     # Get values to build transition render sequence
     # Divide transition lenght between clips, odd frame goes to from_clip 
-    real_length = length + 1 # first frame is 100% from clip frame so we are going to have to drop that
-    to_part = real_length / 2
+    real_length = length + 1 # first frame is 100% a from_clip frame so we are going to have to drop that
+    to_part = real_length // 2
     from_part = real_length - to_part
 
     # HACKFIX, I just tested this till it worked, not entirely sure on math here
@@ -1038,15 +957,63 @@ def _add_transition_dialog_callback(dialog, response_id, selection_widgets, tran
         add_thingy = 0
     else:
         add_thingy = 1
+
+    # Get required handle lengths.
+    from_req = from_part - add_thingy
+    to_req = to_part - (1 - add_thingy)
+    from_handle = transition_data["from_handle"]
+    to_handle = transition_data["to_handle"]
+    from_clip_index = movemodes.selected_range_in
     
-    if _check_transition_handles((from_part - add_thingy),
-                                 transition_data["from_handle"], 
-                                 to_part - (1 - add_thingy), 
-                                 transition_data["to_handle"],
-                                 length) == False:
-        return
-    
-    editorstate.transition_length = length
+    # Check that we have enough handles
+    if from_req > from_handle or to_req > to_handle:
+        if force_steal_frames == False:
+            _show_no_handles_dialog( from_req,
+                                     from_handle, 
+                                     to_req,
+                                     to_handle,
+                                     length)
+            return
+
+        # Force trim from clip if needed
+        from_needed = from_req - from_handle
+        if from_needed > 0:
+            if from_needed + 1 < from_clip.clip_length():
+                data = {"track":transition_data["track"],
+                        "clip":transition_data["from_clip"],
+                        "index":from_clip_index,
+                        "delta":-from_needed,
+                        "undo_done_callback":None, # we're not doing the callback because we are not in trim tool that needs it
+                        "first_do":False} # setting this False prevents callback
+                action = edit.trim_end_action(data)
+                edit.do_gui_update = False
+                action.do_edit()
+                edit.do_gui_update = True
+            else:
+                # Clip is not long enough for frame steeling, transition fails.
+                _show_failure_to_steal_frames_dialog(from_needed, from_clip.clip_length(), -1, -1)
+                return
+                
+        # Force trim to clip if needed
+        to_needed = to_req - to_handle
+        if to_needed > 0:
+            if to_needed + 1 < to_clip.clip_length():
+                data = {"track":transition_data["track"],
+                        "clip":transition_data["to_clip"],
+                        "index":from_clip_index + 1,
+                        "delta":to_needed,
+                        "undo_done_callback":None, # we're not doing the callback because we are not in trim tool that needs it
+                        "first_do":False} # setting this False prevents callback
+                action = edit.trim_start_action(data)
+                edit.do_gui_update = False
+                action.do_edit()
+                edit.do_gui_update = True
+            else:
+                # Clip is not long enough for frame steeling, transition fails.
+                _show_failure_to_steal_frames_dialog(-1, -1, to_needed, to_clip.clip_length())
+                return
+
+    editorstate.transition_length = length # Saved for user so that last length becomes default for next invocation.
     
     # Get from in and out frames
     from_in = from_clip.clip_out - from_part + add_thingy
@@ -1056,10 +1023,13 @@ def _add_transition_dialog_callback(dialog, response_id, selection_widgets, tran
     to_in = to_clip.clip_in - to_part - 1 
     to_out = to_in + length # or transition will include one frame too many
 
-    # Edit clears selection, get track index before selection is cleared
-    trans_index = movemodes.selected_range_out
+    # Edit clears selection, get transition index before selection is cleared
+    trans_index = from_clip_index + 1
     movemodes.clear_selected_clips()
 
+    # Save encoding
+    PROJECT().set_project_property(appconsts.P_PROP_TRANSITION_ENCODING, (encoding_option_index, quality_option_index))
+
     producer_tractor = mlttransitions.get_rendered_transition_tractor(  editorstate.current_sequence(),
                                                                         from_clip,
                                                                         to_clip,
@@ -1083,7 +1053,7 @@ def _add_transition_dialog_callback(dialog, response_id, selection_widgets, tran
                                                 
     # Save transition data into global variable to be available at render complete callback
     global transition_render_data
-    transition_render_data = (trans_index, from_clip, to_clip, transition_data["track"], from_in, to_out, transition_type_selection_index, creation_data)
+    transition_render_data = (trans_index, from_clip, to_clip, transition_data["track"], from_in, to_out, transition_type_selection_index, creation_data, add_thingy)
     window_text, type_id = mlttransitions.rendered_transitions[transition_type_selection_index]
     window_text = _("Rendering ") + window_text
 
@@ -1095,10 +1065,10 @@ def _add_transition_dialog_callback(dialog, response_id, selection_widgets, tran
                                                 window_text)
 
 def _transition_render_complete(clip_path):
-    print "Render complete"
+    print("Render complete")
 
     global transition_render_data
-    transition_index, from_clip, to_clip, track, from_in, to_out, transition_type, creation_data = transition_render_data
+    transition_index, from_clip, to_clip, track, from_in, to_out, transition_type, creation_data, length_fix = transition_render_data
 
     transition_clip = current_sequence().create_rendered_transition_clip(clip_path, transition_type)
     transition_clip.creation_data = creation_data
@@ -1109,7 +1079,8 @@ def _transition_render_complete(clip_path):
             "to_clip":to_clip,
             "track":track,
             "from_in":from_in,
-            "to_out":to_out}
+            "to_out":to_out,
+            "length_fix":length_fix}
 
     action = edit.add_centered_transition_action(data)
     action.do_edit()
@@ -1196,69 +1167,124 @@ def _transition_RE_render_complete(clip_path):
     action = edit.replace_centered_transition_action(data)
     action.do_edit()
 
-def _check_transition_handles(from_req, from_handle, to_req, to_handle, length):
+def _show_no_handles_dialog(from_req, from_handle, to_req, to_handle, length):
+    SPACE_TAB = "    "
+    info_text = _("To create a rendered transition you need enough media overlap from both clips!\n\n")
+    first_clip_info = None
+    if from_req > from_handle:
 
-    if from_req > from_handle or to_req  > to_handle:
-        SPACE_TAB = "    "
-        info_text = _("To create a rendered transition you need enough media overlap from both clips!\n\n")
-        first_clip_info = None
-        if from_req > from_handle:
-        
-            first_clip_info = \
-                        _("<b>FIRST CLIP MEDIA OVERLAP:</b>  ") + \
-                        SPACE_TAB + _("Available <b>") + str(from_handle) + _("</b> frame(s), " ) + \
-                        SPACE_TAB + _("Required <b>") + str(from_req) + _("</b> frame(s)")
+        first_clip_info = \
+                    _("<b>FIRST CLIP MEDIA OVERLAP:</b>  ") + \
+                    SPACE_TAB + _("Available <b>") + str(from_handle) + _("</b> frame(s), " ) + \
+                    SPACE_TAB + _("Required <b>") + str(from_req) + _("</b> frame(s)") + "\n"  + \
+                    SPACE_TAB + _("Trim first clip end back <b>") + str(from_req) + _("</b> frame(s)") + "\n"
+
+    second_clip_info = None
+    if to_req  > to_handle:
+        second_clip_info = \
+                        _("<b>SECOND CLIP MEDIA OVERLAP:</b> ") + \
+                        SPACE_TAB + _("Available <b>") + str(to_handle) + _("</b> frame(s), ") + \
+                        SPACE_TAB + _("Required <b>") + str(to_req) + _("</b> frame(s) ") + "\n" + \
+                        SPACE_TAB + _("Trim second clip start forward <b>") + str(from_req) + _("</b> frame(s)") + "\n"
+
+    img = Gtk.Image.new_from_file ((respaths.IMAGE_PATH + "transition_wrong.png"))
+    img2 = Gtk.Image.new_from_file ((respaths.IMAGE_PATH + "transition_right.png"))
+    img2.set_margin_bottom(24)
+
+    label1 = Gtk.Label(_("Current situation, not enought media overlap:"))
+    label1.set_margin_bottom(12)
+    label2 = Gtk.Label(_("You need more media overlap:"))
+    label2.set_margin_bottom(12)
+    label2.set_margin_top(24)
+    label3 = Gtk.Label(info_text)
+    label3.set_use_markup(True)
+    if first_clip_info != None:
+        label4 = Gtk.Label(first_clip_info)
+        label4.set_use_markup(True)
+    if second_clip_info != None:
+        label5 = Gtk.Label(second_clip_info)
+        label5.set_use_markup(True)
+
+    row1 = guiutils.get_centered_box([label1])
+    row2 = guiutils.get_centered_box([img])
+    row3 = guiutils.get_centered_box([label2])
+    row4 = guiutils.get_centered_box([img2])
+    row5 = guiutils.get_centered_box([label3])
+
+    rows = [row1, row2, row3, row4]
 
 
-        second_clip_info = None
-        if to_req  > to_handle:
-            second_clip_info = \
-                            _("<b>SECOND CLIP MEDIA OVERLAP:</b> ") + \
-                            SPACE_TAB + _("Available <b>") + str(to_handle) + _("</b> frame(s), ") + \
-                            SPACE_TAB + _("Required <b>") + str(to_req) + _("</b> frame(s) ")
+    if first_clip_info != None:
+        row6 = guiutils.get_left_justified_box([label4])
+        rows.append(row6)
+    if second_clip_info != None:
+        row7 = guiutils.get_left_justified_box([label5])
+        rows.append(row7)
+    
+    label = Gtk.Label(_("Activating 'Steal frames from clips if needed' checkbox can help too."))
+    row = guiutils.get_left_justified_box([label])
+    row.set_margin_top(24)
+    rows.append(row)
 
-        
-        img = Gtk.Image.new_from_file ((respaths.IMAGE_PATH + "transition_wrong.png"))
-        img2 = Gtk.Image.new_from_file ((respaths.IMAGE_PATH + "transition_right.png"))
-        img2.set_margin_bottom(24)
+    dialogutils.warning_message_with_panels(_("More media overlap needed to create transition!"), 
+                                            "", gui.editor_window.window, True, dialogutils.dialog_destroy, rows)
+            
+def _show_failure_to_steal_frames_dialog(from_needed, from_length, to_needed, to_length):
+    SPACE_TAB = "    "
+    info_text = _("To create a rendered Transition you need enough media overlap from both Clips!\n\n")
+    first_clip_info = None
+    if from_needed > 0:
 
-        label1 = Gtk.Label(_("Current situation, not enought media overlap:"))
+        first_clip_info = \
+                    _("<b>FIRST CLIP:</b>  ") + \
+                    SPACE_TAB + _("Length <b>") + str(from_length) + _("</b> frame(s), " ) + \
+                    SPACE_TAB + _("Required shortning <b>") + str(from_needed) + _("</b> frame(s)")
+
+
+    second_clip_info = None
+    if to_needed  > 0:
+        second_clip_info = \
+                        _("<b>SECOND CLIP:</b> ") + \
+                        SPACE_TAB + _("Length <b>") + str(to_length) + _("</b> frame(s), ") + \
+                        SPACE_TAB + _("Required shortning <b>") + str(to_needed) + _("</b> frame(s) ")
+
+    rows = []
+    if first_clip_info != None:
+        first_clip_info_label = Gtk.Label(first_clip_info)
+        first_clip_info_label.set_use_markup(True)
+        row = guiutils.get_left_justified_box([first_clip_info_label])
+        rows.append(row)
+        label1 = Gtk.Label("\u2022" + " " + _("Lengthen first Clip from beginning:"))
         label1.set_margin_bottom(12)
-        label2 = Gtk.Label(_("You need more media overlap:"))
-        label2.set_margin_bottom(12)
-        label2.set_margin_top(24)
-        label3 = Gtk.Label(info_text)
-        label3.set_use_markup(True)
-        if first_clip_info != None:
-            label4 = Gtk.Label(first_clip_info)
-            label4.set_use_markup(True)
-        if second_clip_info != None:
-            label5 = Gtk.Label(second_clip_info)
-            label5.set_use_markup(True)
-        
-        row1 = guiutils.get_centered_box([label1])
+        label1.set_margin_top(24)
+        img = Gtk.Image.new_from_file ((respaths.IMAGE_PATH + "transition_fix_first_clip.png"))
+        row1 = guiutils.get_left_justified_box([guiutils.pad_label(40,12), label1])
         row2 = guiutils.get_centered_box([img])
-        row3 = guiutils.get_centered_box([label2])
-        row4 = guiutils.get_centered_box([img2])
-        row5 = guiutils.get_centered_box([label3])
-        
-        rows = [row1, row2, row3, row4]
+        rows.append(row1)
+        rows.append(row2)
+        label2 = Gtk.Label("\u2022" + " " + _("or make Transition shorter."))
+        row1 = guiutils.get_left_justified_box([guiutils.pad_label(40,12), label2])
+        rows.append(row1)
 
-        
-        if first_clip_info != None:
-            row6 = guiutils.get_left_justified_box([label4])
-            rows.append(row6)
-        if second_clip_info != None:
-            row7 = guiutils.get_left_justified_box([label5])
-            rows.append(row7)
-        
+    if second_clip_info != None:
+        last_clip_info_label = Gtk.Label(second_clip_info)
+        last_clip_info_label.set_use_markup(True)
+        row = guiutils.get_left_justified_box([last_clip_info_label])
+        rows.append(row)
+        label1 = Gtk.Label("\u2022" + " " + _("Lengthen second Clip from end:"))
+        label1.set_margin_bottom(12)
+        label1.set_margin_top(24)
+        img = Gtk.Image.new_from_file ((respaths.IMAGE_PATH + "transition_fix_last_clip.png"))
+        row1 = guiutils.get_left_justified_box([guiutils.pad_label(40,12), label1])
+        row2 = guiutils.get_centered_box([img])
+        rows.append(row1)
+        rows.append(row2)
+        label2 = Gtk.Label("\u2022" + " " + _("or make Transition shorter."))
+        row1 = guiutils.get_left_justified_box([guiutils.pad_label(40,12), label2])
+        rows.append(row1)
 
-        dialogutils.warning_message_with_panels(_("More media overlap needed to create transition!"), 
-                                                "", gui.editor_window.window, True, dialogutils.dialog_destroy, rows)
-                
-        return False
-
-    return True
+    dialogutils.warning_message_with_panels(_("<b>Stealing frames from clips to transition failed!</b>"), 
+                                            "", gui.editor_window.window, True, dialogutils.dialog_destroy, rows)
 
 def _do_rendered_fade(track):
     clip = track.clips[movemodes.selected_range_in]
@@ -1293,10 +1319,10 @@ def _add_fade_dialog_callback(dialog, response_id, selection_widgets, transition
 
     try:
         length = int(length_entry.get_text())
-    except Exception, e:
+    except Exception as e:
         # INFOWINDOW, bad input
-        print str(e)
-        print "entry"
+        print(str(e))
+        print("entry")
         return
 
     dialog.destroy()
@@ -1335,7 +1361,7 @@ def _add_fade_dialog_callback(dialog, response_id, selection_widgets, transition
                                                                         transition_type_selection_index,
                                                                         None,
                                                                         color_str)
-    print "producer_tractor length:" + str(producer_tractor.get_length())
+    print("producer_tractor length:" + str(producer_tractor.get_length()))
 
     # Creation data struct needs to have same members for transitions and fades, hence a lot of None here.
     # Used for rerender functionality.
@@ -1444,7 +1470,7 @@ def _fade_RE_render_dialog_callback(dialog, response_id, selection_widgets, fade
                                                                         transition_type_index,
                                                                         None,
                                                                         color_str)
-    print "producer_tractor length:" + str(producer_tractor.get_length())
+    print("producer_tractor length:" + str(producer_tractor.get_length()))
 
     fade_clip_index = track.clips.index(orig_fade_clip)
     
@@ -1534,10 +1560,10 @@ class ReRenderderAllWindow:
         self.rerender_list = rerender_list
         self.rendered_items = []
         self.encoding_selections = encoding_selections
-        self.dialog = Gtk.Dialog(_("Rerender all Rendered Transitions / Fades").encode('utf-8'),
+        self.dialog = Gtk.Dialog(_("Rerender all Rendered Transitions / Fades"),
                          gui.editor_window.window,
                          Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                         (_("Cancel").encode('utf-8'), Gtk.ResponseType.REJECT))
+                         (_("Cancel"), Gtk.ResponseType.REJECT))
         self.current_item = 0
         self.runner_thread = None
         self.renderer = None
@@ -1589,8 +1615,8 @@ class ReRenderderAllWindow:
 
         # Dreate render consumer
         profile = PROJECT().profile
-        folder = editorpersistance.prefs.render_folder
-        file_name = md5.new(str(os.urandom(32))).hexdigest()
+        folder = userfolders.get_render_dir()
+        file_name = hashlib.md5(str(os.urandom(32)).encode('utf-8')).hexdigest()
         self.write_file = folder + "/"+ file_name + file_ext
         consumer = renderconsumer.get_render_consumer_for_encoding_and_quality(self.write_file, profile, encoding_option_index, quality_option_index)
         
@@ -1811,18 +1837,8 @@ def mouse_dragged_out(event):
 
 # --------------------------------------------------- copy/paste
 def do_timeline_objects_copy():
-    if _timeline_has_focus() == False:
-        # try to extract text to clipboard because user pressed CTRL + C
-        copy_source = gui.editor_window.window.get_focus()
-        try:
-            copy_source.copy_clipboard()
-        except:# selected widget was not a Gtk.Editable that can provide text to clipboard
-            pass
-
-        return 
-
     if compositormodes.compositor != None and compositormodes.compositor.selected == True:
-        editorstate.set_copy_paste_objects((COPY_PASTA_DATA_COMPOSITOR_PROPERTIES, compositormodes.compositor.get_copy_paste_objects()))
+        editorstate.set_copy_paste_objects((COPY_PASTE_DATA_COMPOSITOR_PROPERTIES, compositormodes.compositor.get_copy_paste_data()))
         return
         
     if movemodes.selected_track != -1:
@@ -1832,13 +1848,10 @@ def do_timeline_objects_copy():
         for i in range(movemodes.selected_range_in, movemodes.selected_range_out + 1):
             clone_clip = current_sequence().clone_track_clip(track, i)
             clone_clips.append(clone_clip)
-        editorstate.set_copy_paste_objects((COPY_PASTA_DATA_CLIPS, clone_clips))
+        editorstate.set_copy_paste_objects((COPY_PASTE_DATA_CLIPS, clone_clips))
         return
 
 def do_timeline_objects_paste():
-    if _timeline_has_focus() == False:
-        return 
-        
     track = current_sequence().get_first_active_track()
     if track == None:
         return 
@@ -1847,7 +1860,7 @@ def do_timeline_objects_paste():
         return 
     
     data_type, paste_clips = paste_objs
-    if data_type != COPY_PASTA_DATA_CLIPS:
+    if data_type != COPY_PASTE_DATA_CLIPS:
         do_compositor_data_paste(paste_objs)
         return
 
@@ -1855,9 +1868,12 @@ def do_timeline_objects_paste():
 
     new_clips = []
     for clip in paste_clips:
-        new_clip = current_sequence().create_clone_clip(clip)
+        if isinstance(clip, int): # blanks, these represented as int's.
+            new_clip = clip 
+        else: # media clips
+            new_clip = current_sequence().create_clone_clip(clip)
         new_clips.append(new_clip)
-    editorstate.set_copy_paste_objects((COPY_PASTA_DATA_CLIPS, new_clips))
+    editorstate.set_copy_paste_objects((COPY_PASTE_DATA_CLIPS, new_clips))
 
     # Paste clips
     editevent.do_multiple_clip_insert(track, paste_clips, tline_pos)
@@ -1875,7 +1891,7 @@ def do_timeline_filters_paste():
         return 
 
     data_type, paste_clips = paste_objs
-    if data_type != COPY_PASTA_DATA_CLIPS:
+    if data_type != COPY_PASTE_DATA_CLIPS:
         do_compositor_data_paste(paste_objs)
         return
         
@@ -1903,8 +1919,8 @@ def do_timeline_filters_paste():
 
 def do_compositor_data_paste(paste_objs):
     data_type, paste_data = paste_objs
-    if data_type != COPY_PASTA_DATA_COMPOSITOR_PROPERTIES:
-        print "supposed unreahcable if in do_compositor_data_paste"
+    if data_type != COPY_PASTE_DATA_COMPOSITOR_PROPERTIES:
+        print("supposed unreahcable if in do_compositor_data_paste")
         return
         
     if compositormodes.compositor != None and compositormodes.compositor.selected == True:
@@ -1965,6 +1981,8 @@ def _marker_add_dialog_callback(dialog, response_id, name_entry):
 
     current_sequence().markers.append((name, current_frame))
     current_sequence().markers = sorted(current_sequence().markers, key=itemgetter(1))
+
+    updater.update_position_bar()
     updater.repaint_tline()
     
 
@@ -1983,3 +2001,5 @@ def set_track_small_height(track_index):
     if editorstate.SCREEN_HEIGHT < 863:
         track.height = appconsts.TRACK_HEIGHT_SMALLEST
 
+
+
