@@ -39,6 +39,7 @@ import time
 import webbrowser
 
 import appconsts
+import atomicfile
 import cairoarea
 import dialogutils
 import editorstate
@@ -59,6 +60,7 @@ import toolguicomponents
 import toolsencoding
 import translations
 import threading
+import userfolders
 import utils
 
 import gmicplayer
@@ -87,7 +89,7 @@ _current_preview_surface = None
 _current_dimensions = None
 _current_fps = None
 _current_profile_index = None
-_render_data = None
+_render_data = None # toolsencoding.ToolsRenderData object
 _last_load_file = None
 
 _startup_data = None
@@ -100,12 +102,29 @@ _hamburger_menu = Gtk.Menu()
 #-------------------------------------------------- launch and inits
 def test_availablity():
     if os.path.exists("/usr/bin/gmic") == True or os.path.exists("/app/bin/gmic") == True: # File system and flatpak
-        print "G'MIC found"
+        print("G'MIC found")
         global _gmic_found
         _gmic_found = True
     else:
-        print "G'MIC NOT found"
+        print("G'MIC NOT found")
 
+def get_gmic_version():
+    gmic_ver = 1
+    cmd = "gmic -version"
+    process = subprocess.Popen(cmd.split(), stdout=subprocess.PIPE)
+    output, error = process.communicate()
+    tokens = output.split()
+    clended = []
+    for token in tokens:
+        token = token.decode("utf-8")
+        str1 = token.replace('.','')
+        str2 = str1.replace(',','')
+        if str2.isdigit(): # this is based on assumtion that str2 ends up being number like "175" or 215" etc. only for version number token
+            if str2[0] == '2':
+                gmic_ver = 2
+
+    return gmic_ver
+                
 def gmic_available():
     return _gmic_found
     
@@ -124,8 +143,8 @@ def launch_gmic(launch_data=None):
         clip, track = launch_data # from guicomponwnts._get_tool_integration_menu_item()
         args = ("path:" + str(clip.path), "clip_in:" + str(clip.clip_in), "clip_out:" + str(clip.clip_out))
         
-    print "Launch gmic..."
-    FLOG = open(utils.get_hidden_user_dir_path() + "log_gmic", 'w')
+    print("Launch gmic...")
+    FLOG = open(userfolders.get_cache_dir() + "log_gmic", 'w')
     if args == None:
         subprocess.Popen([sys.executable, respaths.LAUNCH_DIR + "flowbladegmic"], stdin=FLOG, stdout=FLOG, stderr=FLOG)
     else:
@@ -156,23 +175,15 @@ def main(root_path, force_launch=False):
     respaths.set_paths(root_path)
 
     # Check G'MIC version
-    cmd = "gmic -version"
-    process = subprocess.Popen(cmd.split(), stdout=subprocess.PIPE)
-    output, error = process.communicate()
-    tokens = output.split()
-    clended = []
-    for token in tokens:
-        str1 = token.replace('.','')
-        str2 = str1.replace(',','')
-        if str2.isdigit(): # this is based on assumtion that str2 ends up being number like "175" or 215" etc. only for version number token
-            if str2[0] == '2':
-                global _gmic_version
-                _gmic_version = 2
-                respaths.set_gmic2(root_path)
+    global _gmic_version
+    _gmic_version = get_gmic_version()
+    if _gmic_version == 2:
+        respaths.set_gmic2(root_path)
 
     # Write stdout to log file
-    sys.stdout = open(utils.get_hidden_user_dir_path() + "log_gmic", 'w')
-    print "G'MIC version:", str(_gmic_version)
+    userfolders.init()
+    sys.stdout = open(userfolders.get_cache_dir() + "log_gmic", 'w')
+    print("G'MIC version:", str(_gmic_version))
 
     # Init gmic tool session dirs
     if os.path.exists(get_session_folder()):
@@ -276,7 +287,7 @@ def init_frames_dirs():
 
 #----------------------------------------------- session folders and files
 def get_session_folder():
-    return utils.get_hidden_user_dir_path() + appconsts.GMIC_DIR + "/session_" + str(_session_id)
+    return userfolders.get_cache_dir() + appconsts.GMIC_DIR + "/session_" + str(_session_id)
 
 def get_clip_frames_dir():
     return get_session_folder() + CLIP_FRAMES_DIR
@@ -388,8 +399,8 @@ def script_menu_item_selected(item, script):
 def save_script_dialog(callback):
     dialog = Gtk.FileChooserDialog(_("Save Gmic Script As"), None, 
                                    Gtk.FileChooserAction.SAVE, 
-                                   (_("Cancel").encode('utf-8'), Gtk.ResponseType.CANCEL,
-                                   _("Save").encode('utf-8'), Gtk.ResponseType.ACCEPT))
+                                   (_("Cancel"), Gtk.ResponseType.CANCEL,
+                                   _("Save"), Gtk.ResponseType.ACCEPT))
     dialog.set_action(Gtk.FileChooserAction.SAVE)
     dialog.set_current_name("gmic_script")
     dialog.set_do_overwrite_confirmation(True)
@@ -400,11 +411,11 @@ def save_script_dialog(callback):
 def _save_script_dialog_callback(dialog, response_id):
     if response_id == Gtk.ResponseType.ACCEPT:
         file_path = dialog.get_filenames()[0]
-        script_file = open(file_path, "w")
         buf = _window.script_view.get_buffer()
         script_text = buf.get_text(buf.get_start_iter(), buf.get_end_iter(), include_hidden_chars=True)
-        script_file.write(script_text)
-        script_file.close()
+        with atomicfile.AtomicFileWriter(file_path, "w") as afw:
+            script_file = afw.get_file()
+            script_file.write(script_text)
         dialog.destroy()
     else:
         dialog.destroy()
@@ -412,8 +423,8 @@ def _save_script_dialog_callback(dialog, response_id):
 def load_script_dialog(callback):
     dialog = Gtk.FileChooserDialog(_("Load Gmic Script"), None, 
                                    Gtk.FileChooserAction.OPEN, 
-                                   (_("Cancel").encode('utf-8'), Gtk.ResponseType.CANCEL,
-                                    _("OK").encode('utf-8'), Gtk.ResponseType.ACCEPT))
+                                   (_("Cancel"), Gtk.ResponseType.CANCEL,
+                                    _("OK"), Gtk.ResponseType.ACCEPT))
     dialog.set_action(Gtk.FileChooserAction.OPEN)
     dialog.set_select_multiple(False)
     dialog.connect('response', callback)
@@ -528,10 +539,10 @@ def render_current_frame_preview():
     _preview_render.start()
 
 def _encode_settings_clicked():
-    toolsencoding.create_widgets(_current_profile_index, True)
+    toolsencoding.create_widgets(_current_profile_index)
         
     global _encoding_panel
-    _encoding_panel = toolsencoding.get_enconding_panel(_render_data)
+    _encoding_panel = toolsencoding.get_encoding_panel(_render_data)
 
     if _render_data == None and toolsencoding.widgets.file_panel.movie_name.get_text() == "movie":
         toolsencoding.widgets.file_panel.movie_name.set_text(os.path.basename(_current_path).split(".")[0] + "_gmic")
@@ -541,8 +552,8 @@ def _encode_settings_clicked():
     dialog = Gtk.Dialog(_("Video Encoding Settings"),
                         _window,
                         Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                        (_("Cancel").encode('utf-8'), Gtk.ResponseType.REJECT,
-                         _("Set Encoding").encode('utf-8'), Gtk.ResponseType.ACCEPT))
+                        (_("Cancel"), Gtk.ResponseType.REJECT,
+                         _("Set Encoding"), Gtk.ResponseType.ACCEPT))
     dialog.vbox.pack_start(align, True, True, 0)
     dialogutils.set_outer_margins(dialog.vbox)
     dialog.set_resizable(False)
@@ -582,7 +593,6 @@ class GmicWindow(Gtk.Window):
 
         app_icon = GdkPixbuf.Pixbuf.new_from_file(respaths.IMAGE_PATH + "flowbladetoolicon.png")
         self.set_icon(app_icon)
-
         hamburger_launcher_surface = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "hamburger.png")
         self.hamburger_launcher = guicomponents.PressLaunch(self.hamburger_launch_pressed, hamburger_launcher_surface)
         
@@ -1088,7 +1098,7 @@ class GmicPreviewRendererer(threading.Thread):
             # For the case the render fails
             shutil.copyfile(get_current_frame_file(), get_preview_file())
         except IOError:
-            # No we have failed to extract a png file from source file
+            # We have failed to extract a png file from source file
             Gdk.threads_enter()
             _window.out_view.override_color((Gtk.StateFlags.NORMAL and Gtk.StateFlags.ACTIVE), Gdk.RGBA(red=1.0, green=0.0, blue=0.0))
             _window.out_view.get_buffer().set_text("Extracting PNG frames from this file failed!")
@@ -1103,15 +1113,16 @@ class GmicPreviewRendererer(threading.Thread):
         
         script_str = "gmic " + get_current_frame_file() + " " + view_text + " -output " +  get_preview_file()
 
-        print "Render preview:", script_str
+        print("Render preview:", script_str)
         
-        FLOG = open(utils.get_hidden_user_dir_path() + "log_gmic_preview", 'w')
+        # Render preview and write log
+        FLOG = open(userfolders.get_cache_dir() + "log_gmic_preview", 'w')
         p = subprocess.Popen(script_str, shell=True, stdin=FLOG, stdout=FLOG, stderr=FLOG)
         p.wait()
         FLOG.close()
      
         # read log
-        f = open(utils.get_hidden_user_dir_path() + "log_gmic_preview", 'r')
+        f = open(userfolders.get_cache_dir() + "log_gmic_preview", 'r')
         out = f.read()
         f.close()
 
@@ -1145,11 +1156,11 @@ class GmicEffectRendererer(threading.Thread):
         self.frames_range_writer = None
         
         self.abort = False
+        self.script_renderer = None
         
         # Refuse to render into user home folder
         out_folder = _window.out_folder.get_filenames()[0] + "/"
         if out_folder == (os.path.expanduser("~") + "/"):
-            #print "home folder"
             return
             
         start_time = time.time()
@@ -1175,7 +1186,7 @@ class GmicEffectRendererer(threading.Thread):
             file_path = os.path.join(folder, frame_file)
             os.remove(file_path)
         
-        # Render clipm frames for range
+        # Render clip frames for range
         mark_in = _player.producer.mark_in
         mark_out = _player.producer.mark_out
         self.length = mark_out - mark_in + 1
@@ -1183,10 +1194,8 @@ class GmicEffectRendererer(threading.Thread):
         self.mark_out = mark_out
         
         frame_name = _window.frame_name.get_text()
-        
-        # jotain controllii frame_namelle
 
-        self.frames_range_writer = gmicplayer.FramesRangeWriter(_current_path, self.frames_update)
+        self.frames_range_writer = gmicplayer.get_frames_range_writer_for_current_profile(_current_path, self.frames_update)
         self.frames_range_writer.write_frames(get_render_frames_dir() + "/", frame_name, mark_in, mark_out)
 
         if self.abort == True:
@@ -1202,58 +1211,16 @@ class GmicEffectRendererer(threading.Thread):
 
         while len(os.listdir(folder)) != self.length:
             time.sleep(0.5)
-            
-        clip_frames = os.listdir(folder)
-
-        frame_count = 1
-        for clip_frame in clip_frames:
-            if self.abort == True:
-                return
-            
-            update_info = _("Rendering frame: ") + str(frame_count) + "/" +  str(self.length)
-
-            Gdk.threads_enter()
-            _window.render_percentage.set_markup("<small>" + update_info + "</small>")
-            _window.render_progress_bar.set_fraction(float(frame_count)/float(self.length))
-            Gdk.threads_leave()
- 
-            file_numbers_list = re.findall(r'\d+', clip_frame)
-            filled_number_str = str(file_numbers_list[0]).zfill(3)
-
-            clip_frame_path = os.path.join(folder, clip_frame)
-            rendered_file_path = out_folder + frame_name + "_" + filled_number_str + ".png"
-            
-            script_str = "gmic " + clip_frame_path + " " + user_script + " -output " +  rendered_file_path
-
-            if frame_count == 1: # first frame displays shell output and does error checking
-                FLOG = open(utils.get_hidden_user_dir_path() + "log_gmic_preview", 'w')
-                p = subprocess.Popen(script_str, shell=True, stdin=FLOG, stdout=FLOG, stderr=FLOG)
-                p.wait()
-                FLOG.close()
-                
-                # read log
-                f = open(utils.get_hidden_user_dir_path() + "log_gmic_preview", 'r')
-                out = f.read()
-                f.close()
-                
-                Gdk.threads_enter()
-                _window.out_view.get_buffer().set_text(out + "Return code:" + str(p.returncode))
-                if p.returncode != 0:
-                    _window.out_view.override_color((Gtk.StateFlags.NORMAL and Gtk.StateFlags.ACTIVE), Gdk.RGBA(red=1.0, green=0.0, blue=0.0))
-                    _window.render_percentage.set_text(_("Render error!"))
-                    Gdk.threads_leave()
-                    return
-                else:
-                    _window.out_view.override_color((Gtk.StateFlags.NORMAL and Gtk.StateFlags.ACTIVE), None)
-                    Gdk.threads_leave()
-            else:
-                FLOG = open(utils.get_hidden_user_dir_path() + "log_gmic_preview", 'w')
-                p = subprocess.Popen(script_str, shell=True, stdin=FLOG, stdout=FLOG, stderr=FLOG)
-                p.wait()
-                FLOG.close()
-
-            frame_count = frame_count + 1
-
+        
+        # Render frames with gmic script
+        self.script_renderer = gmicplayer.FolderFramesScriptRenderer(   user_script, 
+                                                                        folder,
+                                                                        out_folder,
+                                                                        frame_name,
+                                                                        self.script_render_update_callback, 
+                                                                        self.script_render_output_callback)
+        self.script_renderer.write_frames()
+        
         # Render video
         if _window.encode_check.get_active() == True:
             # Render consumer
@@ -1272,6 +1239,8 @@ class GmicEffectRendererer(threading.Thread):
             resource_path = out_folder + "/" + resource_name_str
             producer = mlt.Producer(profile, str(resource_path))
 
+            clip_frames = os.listdir(get_render_frames_dir())
+
             self.render_player = renderconsumer.FileRenderPlayer("", producer, consumer, 0, len(clip_frames) - 1)
             self.render_player.wait_for_producer_end_stop = False
             self.render_player.start()
@@ -1279,6 +1248,10 @@ class GmicEffectRendererer(threading.Thread):
             while self.render_player.stopped == False:
 
                 if self.abort == True:
+                    Gdk.threads_enter()
+                    _window.render_percentage.set_markup("<small>" + _("Render stopped!") + "</small>")
+                    _window.render_progress_bar.set_fraction(0.0)
+                    Gdk.threads_leave()
                     return
                 
                 fraction = self.render_player.get_render_fraction()
@@ -1298,7 +1271,7 @@ class GmicEffectRendererer(threading.Thread):
         
     def frames_update(self, frame):
         if frame - self.mark_in < 0:
-            frame = self.length # hack fix, producer suddenly changes the frame i thinks it is in
+            frame = self.length # hack fix, producer suddenly changes the frame it thinks it is in
         else:
             frame = frame - self.mark_in # producer returns original clip frames
         
@@ -1309,9 +1282,32 @@ class GmicEffectRendererer(threading.Thread):
         _window.render_progress_bar.set_fraction(float(frame + 1)/float(self.length))
         Gdk.threads_leave()
 
+    def script_render_update_callback(self, frame_count):
+        update_info = _("Rendering frame: ") + str(frame_count) + "/" +  str(self.length)
+
+        Gdk.threads_enter()
+        _window.render_percentage.set_markup("<small>" + update_info + "</small>")
+        _window.render_progress_bar.set_fraction(float(frame_count)/float(self.length))
+        Gdk.threads_leave()
+
+    def script_render_output_callback(self, p, out):
+        Gdk.threads_enter()
+        _window.out_view.get_buffer().set_text(out + "Return code:" + str(p.returncode))
+        if p.returncode != 0:
+            _window.out_view.override_color((Gtk.StateFlags.NORMAL and Gtk.StateFlags.ACTIVE), Gdk.RGBA(red=1.0, green=0.0, blue=0.0))
+            _window.render_percentage.set_text(_("Render error!"))
+            Gdk.threads_leave()
+            return
+        else:
+            _window.out_view.override_color((Gtk.StateFlags.NORMAL and Gtk.StateFlags.ACTIVE), None)
+            Gdk.threads_leave()
+
     def abort_render(self):
         self.abort = True
 
+        if self.script_renderer != None:
+             self.script_renderer.abort_rendering()
+
         self.shutdown()
                          
         _window.render_percentage.set_markup("<small>" + _("Render stopped!") + "</small>")
