@@ -23,6 +23,7 @@ Module contains GUI update routines.
 """
 import time
 
+from gi.repository import GObject
 from gi.repository import Gtk
 from gi.repository import Gdk
 
@@ -123,14 +124,21 @@ def refresh_player(e):
 
 # --------------------------------- window 
 def window_resized():
-    # Resize track heights so that all tracks are displayed
-    current_sequence().resize_tracks_to_fit(gui.tline_canvas.widget.get_allocation())
-    
-    # Place clips in the middle of timeline canvas after window resize
-    tlinewidgets.set_ref_line_y(gui.tline_canvas.widget.get_allocation())
+    try:
+        # Resize track heights so that all tracks are displayed
+        current_sequence().resize_tracks_to_fit(gui.tline_canvas.widget.get_allocation())
+        
+        # Place clips in the middle of timeline canvas after window resize
+        tlinewidgets.set_ref_line_y(gui.tline_canvas.widget.get_allocation())
 
-    gui.tline_column.init_listeners() # hit areas for track switches need to be recalculated
-    repaint_tline()
+        gui.tline_column.init_listeners() # hit areas for track switches need to be recalculated
+        repaint_tline()
+
+        return False
+    except:
+        GObject.timeout_add(200, window_resized)
+        print("window resized FAILED")
+        return False
 
 # --------------------------------- timeline
 # --- REPAINT
@@ -139,7 +147,9 @@ def repaint_tline():
     Repaints timeline canvas and scale
     """
     gui.tline_canvas.widget.queue_draw()
+    gui.tline_column.widget.queue_draw()
     gui.tline_scale.widget.queue_draw()
+    gui.tline_render_strip.widget.queue_draw()
 
 # --- SCROLL AND LENGTH EVENTS
 def update_tline_scrollbar():
@@ -164,8 +174,9 @@ def update_tline_scrollbar():
         pos = 0.0
 
     # Create and set adjustment
-    adjustment = Gtk.Adjustment(pos, 0.0, 100.0, 
-                                1.0, 10.0, page_size)
+    page_size_in = page_size
+    adjustment = Gtk.Adjustment(value=pos, lower=0.0, upper=100.0, 
+                                step_increment=1.0, page_increment=10.0, page_size=page_size_in)
     adjustment.connect("value-changed", tline_scrolled)
     try: # when testing this might get called before gui is build
         gui.tline_scroll.set_adjustment(adjustment)
@@ -221,7 +232,7 @@ def update_pix_per_frame_full_view():
     Called at sequence init to display full sequence.
     """
     global pix_per_frame_full_view
-    length = current_sequence().get_length() + 5 # +5 is just selected end pad so that end of movie is visible
+    length = current_sequence().get_length() + (20.0 + current_sequence().get_length() * 0.1) # we added some length to make there always be some space after sequence end to to drag and drop
     pix_per_frame_full_view = float(gui.tline_canvas.widget.get_allocation().width) / length
 
 def set_info_icon(info_icon_id):
@@ -384,7 +395,7 @@ def display_clip_in_monitor(clip_monitor_currently_active=False):
     # This makes them reasonably short and trimmable in both directions.
     if clip_producer.media_type == appconsts.IMAGE or clip_producer.media_type == appconsts.PATTERN_PRODUCER:
         if  clip_producer.mark_in == -1 and clip_producer.mark_out == -1:
-            center_frame = clip_producer.get_length() / 2
+            center_frame = clip_producer.get_length() // 2
             default_length_half = 75
             mark_in = center_frame - default_length_half
             mark_out = center_frame + default_length_half - 1
@@ -421,10 +432,12 @@ def display_clip_in_monitor(clip_monitor_currently_active=False):
 
 def display_monitor_clip_name():#we're displaying length and range length also
     clip_len = utils.get_tc_string(gui.pos_bar.producer.get_length())
-    range_info = _get_marks_range_info_text(MONITOR_MEDIA_FILE().mark_in, MONITOR_MEDIA_FILE().mark_out)
+    range_info = _get_marks_range_info(MONITOR_MEDIA_FILE().mark_in, MONITOR_MEDIA_FILE().mark_out)
 
-    gui.editor_window.monitor_source.set_text(MONITOR_MEDIA_FILE().name + " - " + clip_len)
-    gui.editor_window.info1.set_text(range_info)
+    gui.editor_window.monitor_tc_info.set_source_name(MONITOR_MEDIA_FILE().name + " - ")
+    gui.editor_window.monitor_tc_info.set_source_tc(clip_len)
+
+    gui.editor_window.monitor_tc_info.set_range_info(*range_info)
 
 def display_sequence_in_monitor():
     """
@@ -461,31 +474,31 @@ def update_seqence_info_text():
         prog_len = 0
     tc_info = utils.get_tc_string(prog_len)
 
-    gui.editor_window.monitor_source.set_text(name + "  -  " + tc_info)
-    range_info = _get_marks_range_info_text(PLAYER().producer.mark_in, PLAYER().producer.mark_out)
-    gui.editor_window.info1.set_text(range_info)
+    gui.editor_window.monitor_tc_info.set_source_name(name + " - ")
+    gui.editor_window.monitor_tc_info.set_source_tc(tc_info)
 
-def _get_marks_range_info_text(mark_in, mark_out):
-    if editorstate.screen_size_small_width() == False:
-        if mark_in != -1:
-            range_info = "] " + utils.get_tc_string(mark_in)
-        else:
-            range_info = "] --:--:--:--" 
+    range_info = _get_marks_range_info(PLAYER().producer.mark_in, PLAYER().producer.mark_out)
+    gui.editor_window.monitor_tc_info.set_range_info(*range_info)
 
-        if mark_out != -1:
-            range_info = range_info + "   [ " + utils.get_tc_string(mark_out) + "   "
-        else:
-            range_info = range_info + "   [ --:--:--:--"  + "   "
+def _get_marks_range_info(mark_in, mark_out):
+
+    if mark_in != -1:
+        mark_in_info = utils.get_tc_string(mark_in)
     else:
-        range_info = ""
+        mark_in_info = "--:--:--:--" 
+
+    if mark_out != -1:
+        mark_out_info = utils.get_tc_string(mark_out)
+    else:
+        mark_out_info = "--:--:--:--"
 
     range_len = mark_out - mark_in + 1 # +1, out incl.
     if mark_in != -1 and mark_out != -1:
-        range_info = range_info + "][ " + utils.get_tc_string(range_len)
+        range_info = utils.get_tc_string(range_len)
     else:
-        range_info = range_info + "][ --:--:--:--" 
+        range_info = "--:--:--:--" 
     
-    return range_info
+    return (mark_in_info, mark_out_info, range_info)
 
 def switch_monitor_display():
     monitorevent.stop_pressed()
@@ -553,6 +566,12 @@ def update_frame_displayers(frame):
     clipeffectseditor.display_kfeditors_tline_frame(frame)
     compositeeditor.display_kfeditors_tline_frame(frame)
 
+def update_position_bar():
+    if timeline_visible():
+        gui.pos_bar.update_display_from_producer(PLAYER().producer)
+    else:
+        gui.pos_bar.update_display_from_producer(gui.pos_bar.producer)
+    
 def update_kf_editor():
     clipeffectseditor.update_kfeditors_positions()
 
