@@ -23,13 +23,15 @@ Helper functions and data
 """
 import time
 
+# TODO: THIS NEEDS TO GO, MAKE NEW utilsgtk.py MODULE.
 import gi
 gi.require_version('Gtk', '3.0')
-from gi.repository import Gtk, GLib
+from gi.repository import Gtk, Gdk
 
 import math
-import md5
+import hashlib
 import os
+import pickle
 import re
 import threading
 import xml.dom.minidom
@@ -155,7 +157,7 @@ def get_tc_frame_with_fps(frame_str, frames_per_sec):
     # calculate corresponding frame
     try:
         times = frame_str.split(":", 4)
-    except expression as identifier:
+    except Exception:
         return 0
 
     # now we calculate the sum of frames that would sum up at corresponding
@@ -188,6 +190,17 @@ def get_tc_string_with_fps(frame, frames_per_sec):
     mins = mins % 60
     return "%02d:%02d:%02d:%02d" % (hours, mins, sec, fr)
 
+def get_tc_string_with_fps_for_filename(frame, frames_per_sec):
+    frames_per_sec = int(round(frames_per_sec))
+
+    fr = frame % frames_per_sec
+    sec = frame / frames_per_sec
+    mins = sec / 60
+    sec = sec % 60
+    hours = mins / 60
+    mins = mins % 60
+    return "%02d-%02d-%02d-%02d" % (hours, mins, sec, fr)
+    
 def get_time_str_for_sec_float(sec):
     mins = sec / 60
     sec = sec % 60
@@ -346,6 +359,38 @@ def file_extension_is_graphics_file(ext):
     else:
         return False
 
+# ------------------------------------------------ module util methods
+def get_media_type(file_path):
+    """
+    Returns media type of file.
+    """
+    if os.path.exists(file_path):
+        mime_type = get_file_type(file_path)
+    else:
+        # IMAGE_SEQUENCE media objects have a MLT formatted resource path that does not
+        # point to an existing file in the file system. 
+        # We're doing a heuristic here to identify those.
+        pros_index = file_path.find("%0")
+        d_index = file_path.find("d.")
+        if pros_index != -1 and d_index != -1:
+            return appconsts.IMAGE_SEQUENCE
+        all_index = file_path.find(".all")
+        if all_index != -1:
+            return appconsts.IMAGE_SEQUENCE
+            
+        return appconsts.FILE_DOES_NOT_EXIST
+        
+    if mime_type.startswith("video"):
+        return appconsts.VIDEO
+    
+    if mime_type.startswith("audio"):
+        return appconsts.AUDIO
+    
+    if mime_type.startswith("image"):
+        return appconsts.IMAGE
+    
+    return appconsts.UNKNOWN
+    
 def get_file_type(file_path):
     name, ext = os.path.splitext(file_path)
     ext = ext.lstrip(".")
@@ -373,7 +418,7 @@ def is_mlt_xml_file(file_path):
 def hex_to_rgb(value):
     value = value.lstrip('#')
     lv = len(value)
-    return tuple(int(value[i:i+lv/3], 16) for i in range(0, lv, lv/3))
+    return tuple(int(value[i:i+lv//3], 16) for i in range(0, lv, lv//3))
 
 def int_to_hex_str(n):
     val = int_to_hex(n)
@@ -423,44 +468,8 @@ def do_nothing():
 def get_unique_name_for_audio_levels_file(media_file_path, profile):
     size_str = str(os.path.getsize(media_file_path))
     fps_str = str(profile.description())
-    file_name = md5.new(media_file_path + size_str + fps_str).hexdigest()
+    file_name = hashlib.md5((media_file_path + size_str + fps_str).encode('utf-8')).hexdigest()
     return file_name
-    
-def get_hidden_user_dir_path():
-    return os.getenv("HOME") + "/.flowblade/"
-
-def get_phantom_disk_cache_folder():
-    return get_hidden_user_dir_path() +  appconsts.PHANTOM_DIR + "/" + appconsts.PHANTOM_DISK_CACHE_DIR
-
-def get_hidden_screenshot_dir_path():
-    return get_hidden_user_dir_path() + "screenshot/"
-
-def get_config_folder():
-    if editorstate.use_xdg:
-        return xdg_config_home()
-    else:
-        return get_hidden_user_dir_path()
-
-def get_data_folder():
-    if editorstate.use_xdg:
-        return xdg_data_home()
-    else:
-        return get_hidden_user_dir_path()
-        
-def get_cache_folder():   
-    if editorstate.use_xdg:
-        return xdg_cache_home()
-    else:
-        return get_hidden_user_dir_path()
-
-def xdg_config_home():
-    return os.path.join(GLib.get_user_config_dir(), "flowblade")
-    
-def xdg_data_home():
-    return os.path.join(GLib.get_user_data_dir(), "flowblade")
-
-def xdg_cache_home():
-    return os.path.join(GLib.get_user_cache_dir(), "flowblade")
 
 def get_img_seq_glob_lookup_name(asset_file_name):
     parts1 = asset_file_name.split("%")
@@ -469,7 +478,7 @@ def get_img_seq_glob_lookup_name(asset_file_name):
     try:
         end = end.split("?")[0]
     except:
-        print "old style img seq name for " + asset_file_name
+        print("old style img seq name for " + asset_file_name)
     
     return start + "*" + end
 
@@ -542,7 +551,7 @@ def update_xml_file_producer_info(resource, info):
     info["fps_den"] = float(profile_node.getAttribute("frame_rate_den"))
     info["progressive"] = int(profile_node.getAttribute("progressive"))
     
-    print info
+    print(info)
     #  <profile description="HD 720p 29.97 fps" width="1280" height="720" progressive="1" sample_aspect_num="1" sample_aspect_den="1" display_aspect_num="16" display_aspect_den="9" frame_rate_num="30000" frame_rate_den="1001" colorspace="0"/>
     
 def is_media_file(file_path):
@@ -684,7 +693,7 @@ _video_file_extensions = [  "avi",
 def start_timing(msg="start timing"):
     global _start_time
     _start_time = time.time()
-    print msg
+    print(msg)
 
 def elapsed_time(msg="elapsed: ", show_in_millis=True):
     elapsed_time = time.time() - _start_time
@@ -694,5 +703,37 @@ def elapsed_time(msg="elapsed: ", show_in_millis=True):
     else:
         unit = "s"
     
-    print msg + " " + str(elapsed_time) + " " + unit
+    print(msg + " " + str(elapsed_time) + " " + unit)
 
+def get_display_monitors_size_data():
+    monitors_size_data = []
+    
+    display = Gdk.Display.get_default()
+    scr_w = Gdk.Screen.width()
+    scr_h = Gdk.Screen.height()
+    monitors_size_data.append((scr_w, scr_h))
+        
+    num_monitors = display.get_n_monitors() # Get number of monitors.
+    if num_monitors == 1:
+        return monitors_size_data
+    else:
+        for monitor_index in range(0, num_monitors):
+            monitor = display.get_monitor(monitor_index)
+            geom = monitor.get_geometry()
+            monitors_size_data.append((geom.width, geom.height))
+        
+        return monitors_size_data
+
+def escape_shell_path(path):
+    path = path.replace(" ", "\ ")
+    path = path.replace("(", "\(")
+    path = path.replace(")", "\)")
+    return path
+
+def unpickle(path):
+    try:
+        f = open(path, "rb")
+        return pickle.load(f)
+    except:
+        f = open(path, 'rb')
+        return pickle.load(f, encoding='latin1') 
